# -*- coding: utf-8 -*-

from ..utils import *


class bloco_1(TrackedAttributesClass):
    """
    BLOCO 1: OUTRAS INFORMAÇÕES
    Este bloco destina-se à prestação de outras informações exigidas pelo fisco.
    """


    class registro_1001(TrackedAttributesClass):
        """
        REGISTRO 1001: ABERTURA DO BLOCO 1
        Este registro deverá ser gerado para abertura do Bloco 1 e indicará se há informações no bloco.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1001, self).__init__()
            self.REG = '1001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = ''  # Indicador de movimento: 0- Bloco com dados informados; 1- Bloco sem dados informados
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_1100(TrackedAttributesClass):
        """
        REGISTRO 1100: REGISTRO DE INFORMAÇÕES SOBRE EXPORTAÇÃO.
        Este registro deve ser preenchido no mês em que se concluir a exportação direta ou indireta pelo efetivo
        exportador.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1100, self).__init__()
            self.REG = '1100'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_DOC = ''  # Informe o tipo de documento: 0 – Declaração de Exportação; 1 - Declaração Simplificada de Exportação.
            self.NRO_DE = ''  # Número da declaração
            self.DT_DE = ''  # Data da declaração (DDMMAAAA)
            self.NAT_EXP = ''  # Preencher com: 0 - Exportação Direta 1 - Exportação Indireta
            self.NRO_RE = ''  # Nº do registro de Exportação
            self.DT_RE = ''  # Data do Registro de Exportação (DDMMAAAA)
            self.CHC_EMB = ''  # Nº do conhecimento de embarque
            self.DT_CHC = ''  # Data do conhecimento de embarque (DDMMAAAA)
            self.DT_AVB = ''  # Data da averbação da Declaração de exportação (ddmmaaaa)
            self.TP_CHC = ''  # Informação do tipo de conhecimento de embarque: 01 – AWB;02 – MAWB;03 – HAWB;04 – COMAT;06 – R. EXPRESSAS;07 – ETIQ. REXPRESSAS;08 – HR. EXPRESSAS;09 – AV7;10 – BL;11 – MBL;12 – HBL;13 – CRT;14 – DSIC;16 – COMAT BL;17 – RWB;18 – HRWB;19 – TIF/DTA;20 – CP2;91 – NÂO IATA;92 – MNAO IATA;93 – HNAO IATA;99 – OUTROS.
            self.PAIS = ''  # Código do país de destino da mercadoria (Preencher conforme tabela do SISCOMEX)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1105(TrackedAttributesClass):
        """
        REGISTRO 1105: DOCUMENTOS FISCAIS DE EXPORTAÇÃO.
        Este registro deve ser apresentado para discriminar os documentos fiscais vinculados à exportação.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1105, self).__init__()
            self.REG = '1105'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo da NF, conforme tabela 4.1.1
            self.SERIE = ''  # Série da Nota Fiscal
            self.NUM_DOC = ''  # Número de Nota Fiscal de Exportação emitida pelo Exportador
            self.CHV_NFE = ''  # Chave da Nota Fiscal Eletrônica
            self.DT_DOC = ''  # Data da emissão da NF de exportação
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1110(TrackedAttributesClass):
        """
        REGISTRO 1110: OPERAÇÕES DE EXPORTAÇÃO INDIRETA - MERCADORIAS DE TERCEIROS.
        Este registro deve ser apresentado para informar a origem das mercadorias adquiridas para a exportação.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1110, self).__init__()
            self.REG = '1110'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = '1105'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''  # Código do participante-Fornecedor da Mercadoria destinada à exportação (campo 02 do Registro 0150)
            self.COD_MOD = ''  # Código do documento fiscal, conforme a Tabela 4.1.1
            self.SER = ''  # Série do documento fiscal recebido com fins específicos de exportação.
            self.NUM_DOC = ''  # Número do documento fiscal recebido com fins específicos de exportação.
            self.DT_DOC = ''  # Data da emissão do documento fiscal recebido com fins específicos de exportação
            self.CHV_NFE = ''  # Chave da Nota Fiscal Eletrônica
            self.NR_MEMO = ''  # Número do Memorando de Exportação
            self.QTD = ''  # Quantidade do item efetivamente exportado.
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1200(TrackedAttributesClass):
        """
        REGISTRO 1200: CONTROLE DE CRÉDITOS FISCAIS - ICMS.
        Este registro demonstra a conta corrente dos créditos fiscais de ICMS, controlados extra-apuração. Cada UF determinará a
        obrigatoriedade de apresentação deste registro.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1200, self).__init__()
            self.REG = '1200'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_AJ_APUR = ''  # Código de ajuste, conforme informado na Tabela indicada no item 5.1.1.
            self.SLD_CRED = ''  # Saldo de créditos fiscais de períodos anteriores
            self.CRED_APR = ''  # Total de crédito apropriado no mês
            self.CRED_RECEB = ''  # Total de créditos recebidos por transferência
            self.CRED_UTIL = ''  # Total de créditos utilizados no período
            self.SLD_CRED_FIM = ''  # Saldo de crédito fiscal acumulado a transportar para o período seguinte
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1210(TrackedAttributesClass):
        """
        REGISTRO 1210: UTILIZAÇÃO DE CRÉDITOS FISCAIS – ICMS.
        Este registro deve ser apresentado para detalhar a utilização de créditos fiscais de ICMS no período. O somatório dos
        valores do campo 04 deste registro deve corresponder ao informado no campo 06 do registro 1200.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1210, self).__init__()
            self.REG = '1210'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1200'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.TIPO_UTIL = ''  # Tipo de utilização do crédito, conforme tabela indicada no item 5.5.
            self.NR_DOC = ''  # Número do documento utilizado na baixa de créditos
            self.VL_CRED_UTIL = ''  # Total de crédito utilizado
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1300(TrackedAttributesClass):
        """
        REGISTRO 1300: MOVIMENTAÇÃO DIÁRIA DE COMBUSTÍVEIS
        Este registro deve ser apresentado pelos contribuintes do ramo varejista de combustíveis (postos de combustíveis).
        Este registro se refere à movimentação diária de combustíveis, havendo apenas um registro por tipo de combustível e por
        data do fechamento da movimentação (campo COD_ITEM e campo DT_FECH), independente de ocorrerem intervenções.
        Não pode haver mais de um registro com o mesmo código de combustível e mesma data de fechamento.

        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1300, self).__init__()
            self.REG = '1300'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_ITEM = ''  # Código do Produto, constante do registro 0200
            self.DT_FECH = ''  # Data do fechamento da movimentação
            self.ESTQ_ABERT = ''  # Estoque no inicio do dia, em litros
            self.VOL_ENTR = ''  # Volume Recebido no dia (em litros)
            self.VOL_DISP = ''  # Volume Disponível (04 + 05), em litros
            self.VOL_SAIDAS = ''  # Volume Total das Saídas, em litros
            self.ESTQ_ESCR = ''  # Estoque Escritural (06 – 07), litros
            self.VAL_AJ_PERDA = ''  # Valor da Perda, em litros
            self.VAL_AJ_GANHO = ''  # Valor do ganho, em litros
            self.FECH_FISICO = ''  # Estoque de Fechamento, em litros
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1310(TrackedAttributesClass):
        """
        REGISTRO 1310: MOVIMENTAÇÃO DIÁRIA DE COMBUSTÍVEIS POR TANQUE
        Este registro deve ser apresentado para informar a movimentação diária por tanque. Não pode haver mais de um
        registro com o mesmo número de tanque.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1310, self).__init__()
            self.REG = '1310'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1300'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_TANQUE = ''  # Tanque que armazena o combustível.
            self.ESTQ_ABERT = ''  # Estoque no inicio do dia, em litros
            self.VOL_ENTR = ''  # Volume Recebido no dia (em litros)
            self.VOL_DISP = ''  # Volume Disponível (03 + 04), em litros
            self.VOL_SAIDAS = ''  # Volume Total das Saídas, em litros
            self.ESTQ_ESCR = ''  # Estoque Escritural(05 – 06), litros
            self.VAL_AJ_PERDA = ''  # Valor da Perda, em litros
            self.VAL_AJ_GANHO = ''  # Valor do ganho, em litros
            self.FECH_FISICO = ''  # Volume aferido no tanque, em litros. Estoque de fechamento físico do tanque.
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1320(TrackedAttributesClass):
        """
        REGISTRO 1320: VOLUME DE VENDAS
        Este registro deve ser apresentado para discriminar o volume das vendas no dia, considerando-se vendas todas as
        saídas promovidas a qualquer título. Não havendo intervenção, haverá apenas um registro por bico e os campos
        NR_INTERV, MOT_INTERV, NOM_INTERV, CNPJ_INTERV e CPF_INTERV estarão sem informação. Para cada
        intervenção ocorrida na bomba associada ao bico, um novo registro deve ser preenchido com dados da intervenção e os
        valores totalizados desde a intervenção até uma próxima intervenção ou o fim do dia.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1320, self).__init__()
            self.REG = '1320'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = '1310'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_BICO = ''  # Bico Ligado à Bomba
            self.NR_INTERV = ''  # Número da intervenção
            self.MOT_INTERV = ''  # Motivo da Intervenção
            self.NOM_INTERV = ''  # Nome do Interventor
            self.CNPJ_INTERV = ''  # CNPJ da empresa responsável pela intervenção
            self.CPF_INTERV = ''  # CPF do técnico responsável pela intervenção
            self.VAL_FECHA = ''  # Valor da leitura final do contador, no fechamento do bico.
            self.VAL_ABERT = ''  # Valor da leitura inicial do contador, na abertura do bico.
            self.VOL_AFERI = ''  # Aferições da Bomba, em litros
            self.VOL_VENDAS = ''  # Vendas (08 – 09 - 10 ) do bico , em litros
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1350(TrackedAttributesClass):
        """
        REGISTRO 1350: BOMBAS
        Este registro deve ser apresentado para discriminar as bombas pertencentes ao varejista.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1350, self).__init__()
            self.REG = '1350'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.SERIE = ''  # Número de Série da Bomba
            self.FABRICANTE = ''  # Nome do Fabricante da Bomba
            self.MODELO = ''  # Modelo da Bomba
            self.TIPO_MEDICAO = ''  # Identificador de medição: 0 - analógico; 1 – digital
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1360(TrackedAttributesClass):
        """
        REGISTRO 1360: LACRES DA BOMBA
        Este registro deve ser apresentado para discriminar os lacres aplicados à bomba referenciada no registro pai.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1360, self).__init__()
            self.REG = '1360'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1350'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_LACRE = ''  # Número do Lacre associado na Bomba
            self.DT_APLICACAO = ''  # Data de aplicação do Lacre
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1370(TrackedAttributesClass):
        """
        REGISTRO 1370: BICOS DA BOMBA
        Este registro deve ser apresentado para discriminar os bicos pertencentes à bomba referenciada no registro pai.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1370, self).__init__()
            self.REG = '1370'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1350'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_BICO = ''  # Número sequencial do bico ligado a bomba
            self.COD_ITEM = ''  # Código do Produto, constante do registro 0200
            self.NUM_TANQUE = ''  # Tanque que armazena o combustível.
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1400(TrackedAttributesClass):
        """
        REGISTRO 1400: INFORMAÇÃO SOBRE VALORES AGREGADOS
        Este registro tem como objetivo fornecer informações para o cálculo do valor adicionado por município, sendo utilizado
        para subsidiar cálculos de índices de participação e deve ser apresentado apenas se a unidade federada do declarante assim
        o exigir.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1400, self).__init__()
            self.REG = '1400'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.MUN = ''  # Código do Município de origem
            self.VALOR = ''  # Valor mensal correspondente ao município
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1500(TrackedAttributesClass):
        """
        REGISTRO 1500: NOTA FISCAL/CONTA DE ENERGIA ELÉTRICA (CÓDIGO 06) – OPERAÇÕES INTERESTADUAIS.
        Este registro deve ser apresentado, nas operações de saída interestaduais, pelos contribuintes do segmento de
        energia elétrica, obrigados ao Convênio 115/2003.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1500, self).__init__()
            self.REG = '1500'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''  # Indicador do tipo de operação: 1- Saída
            self.IND_EMIT = ''  # Indicador do emitente do documento fiscal: 0- Emissão própria;
            self.COD_PART = ''  # Código do participante (campo 02 do Registro 0150): - do adquirente, no caso das saídas.
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''  # Código da situação do documento fiscal, conforme a Tabela 4.1.2
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subsérie do documento fiscal
            self.COD_CONS = ''  # Código de classe de consumo de energia elétrica: 01 - Comercial 02 - Consumo Próprio 03 - Iluminação Pública 04 - Industrial 05 - Poder Público 06 - Residencial 07 - Rural 08 -Serviço Público
            self.NUM_DOC = ''  # Número do documento fiscal
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.DT_E_S = ''  # Data da entrada ou da saída
            self.VL_DOC = ''  # Valor total do documento fiscal
            self.VL_DESC = ''  # Valor total do desconto
            self.VL_FORN = ''  # Valor total fornecido/consumido
            self.VL_SERV_NT = ''  # Valor total dos serviços não-tributados pelo ICMS
            self.VL_TERC = ''  # Valor total cobrado em nome de terceiros
            self.VL_DA = ''  # Valor total de despesas acessórias indicadas no documento fiscal
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor acumulado do ICMS
            self.VL_BC_ICMS_ST = ''  # Valor acumulado da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor acumulado do ICMS retido por substituição tributária
            self.COD_INF = ''  # Código da informação complementar do documento fiscal (campo 02 do Registro 0450)
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.TP_LIGACAO = ''  # Código de tipo de Ligação 1 - Monofásico 2 - Bifásico 3 - Trifásico
            self.COD_GRUPO_TENSA = ''  # Código de grupo de tensão:01 - A1 - Alta Tensão (230kV ou mais) 02 - A2 - Alta Tensão (88 a 138kV) 03 - A3 - Alta Tensão (69kV) 04 - A3a - Alta Tensão (30kV a 44kV) 05 - A4 - Alta Tensão (2,3kV a 25kV) 06 - AS - Alta Tensão Subterrâneo 06 07 - B1 - Residencial 07 08 - B1 - Residencial Baixa Renda 08 09 - B2 - Rural 09 10 - B2 - Cooperativa de Eletrificação Rural 11 - B2 - Serviço Público de Irrigação 12 - B3 - Demais Classes 13 - B4a - Iluminação Pública - rede de distribuição 14 - B4b - Iluminação Pública - bulbo de lâmpada
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1510(TrackedAttributesClass):
        """
        REGISTRO 1510: ITENS DO DOCUMENTO NOTA FISCAL/CONTA ENERGIA ELÉTRICA (CÓDIGO 06)
        Este registro deve ser apresentado para informar os itens das Notas Fiscais/Contas de Energia Elétrica (código 06
        da Tabela Documentos Fiscais do ICMS) apresentadas nos registros 1500.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1510, self).__init__()
            self.REG = '1510'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''  # Número sequencial do item no documento fiscal
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.COD_CLASS = ''  # Código de classificação do item de energia elétrica, conforme a Tabela 4.4.1
            self.QTD = ''  # Quantidade do item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor do item
            self.VL_DESC = ''  # Valor total do desconto
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.VL_BC_ICMS = ''  # Valor da base de cálculo do ICMS
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_ICMS = ''  # Valor do ICMS creditado/debitado
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo referente à substituição tributária
            self.ALIQ_ST = ''  # Alíquota do ICMS da substituição tributária na unidade da federação de destino
            self.VL_ICMS_ST = ''  # Valor do ICMS referente à substituição tributária
            self.IND_REC = ''  # Indicador do tipo de receita: 0- Receita própria; 1- Receita de terceiros
            self.COD_PART = ''  # Código do participante receptor da receita, terceiro da operação (campo 02 do Registro 0150)
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1600(TrackedAttributesClass):
        """
        REGISTRO 1600: TOTAL DAS OPERAÇÕES COM CARTÃO DE CRÉDITO E/OU DÉBITO
        Este registro destina-se a identificar o valor total das operações de vendas realizadas pelo declarante cujo
        recebimento pelo estabelecimento tenha sido por cartão de débito ou de crédito, discriminado por administradora. Deve ser
        informado o valor total dos recebimentos em cartões excluídos os estornos, cancelamentos e outros recebimentos não
        vinculados à sua atividade operacional. A obrigatoriedade deste registro deve ser verificada junto a cada uma das unidades
        federativas.
        """

        _order = []

        def __init__(self):
            super(bloco_1.registro_1600, self).__init__()
            self.REG = '1600'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''  # Código do participante (campo 02 do Registro 0150):identificação da administradora do cartão de débito/crédito
            self.TOT_CREDITO = ''  # Valor total das operações realizadas no período referente a Cartão de Crédito
            self.TOT_DEBITO = ''  # Valor total das operações realizadas no período referente a Cartão de Débito
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1700(TrackedAttributesClass):
        """
        REGISTRO 1700 - DOCUMENTOS FISCAIS UTILIZADOS
        Neste registro devem ser informados os dispositivos autorizados e utilizados na emissão de documentos fiscais no período
        da EFD. A obrigatoriedade deste registro deve ser verificada junto a cada uma das unidades federativas.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1700, self).__init__()
            self.REG = '1700'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_DISP = ''  # Código dispositivo autorizado: 00 - Formulário de Segurança – impressor autônomo 01 - FS-DA – Formulário de Segurança para Impressão de DANFE 02 – Formulário de segurança - NF-e 03 - Formulário Contínuo 04 – Blocos 05 - Jogos Soltos
            self.COD_MOD = ''  # Código do modelo do dispositivo autorizado, conforme a Tabela 4.1.1
            self.SER = ''  # Série do dispositivo autorizado
            self.SUB = ''  # Subsérie do dispositivo autorizado
            self.NUM_DOC_INI = ''  # Número do dispositivo autorizado (utilizado) inicial
            self.NUM_DOC_FIN = ''  # Número do dispositivo autorizado (utilizado) final
            self.NUM_AUT = ''  # Número da autorização, conforme dispositivo autorizado
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1710(TrackedAttributesClass):
        """
        REGISTRO 1710 - DOCUMENTOS FISCAIS CANCELADOS/INUTILIZADOS
        Neste registro devem ser informados os documentos cancelados/inutilizados no intervalo constante do registro 1700.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1710, self).__init__()
            self.REG = '1710'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DOC_INI = ''  # Número do dispositivo autorizado (inutilizado) inicial
            self.NUM_DOC_FIN = ''  # Número do dispositivo autorizado (inutilizado) final
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1800(TrackedAttributesClass):
        """
        REGISTRO 1800 – DCTA – DEMONSTRATIVO DE CRÉDITO DO ICMS SOBRE TRANSPORTE AÉREO
        Este registro deve ser informado, pelas empresas de transporte aéreo, para explicitar os estornos de créditos de
        ICMS.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1800, self).__init__()
            self.REG = '1800'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_CARGA = ''  # Valor das prestações cargas (Tributado)
            self.VL_PASS = ''  # Valor das prestações passageiros/cargas (Não Tributado)
            self.VL_FAT = ''  # Valor total do faturamento (2+3)
            self.IND_RAT = ''  # Índice para rateio(2 / 4)
            self.VL_ICMS_ANT = ''  # Valor total dos créditos do ICMS
            self.VL_BC_ICMS = ''  # Valor da base de cálculo do ICMS
            self.VL_ICMS_APUR = ''  # Valor do ICMS apurado no cálculo (5 x 6)
            self.VL_BC_ICMS_APUR = ''  # Valor da base de cálculo do ICMS apurada (5 x 7)
            self.VL_DIF = ''  # Valor da diferença a ser levada a estorno de crédito na apuração     (6 - 8)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1900(TrackedAttributesClass):
        """
        REGISTRO 1900: INDICADOR DE SUB-APURAÇÃO DO ICMS
        Este registro tem por objetivo escriturar o ICMS de operações especificadas em legislação estadual como
        obrigadas a apurações em separado. A princípio, este registro deverá ser apresentado somente pelos contribuintes dos
        estados do Pará e do Espírito Santo, sujeito a outras apurações.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1900, self).__init__()
            self.REG = '1900'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '1001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_APUR_ICMS = ''  # Indicador de outra apuração do ICMS: 3 – APURAÇÃO 1; 4 – APURAÇÃO 2; 5 – APURAÇÃO 3.
            self.DESCR_COMPL_OUT_APUR = ''  # Descrição complementar de Outra Apuração do ICMS
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1910(TrackedAttributesClass):
        """
        REGISTRO 1910: PERÍODO DA SUB-APURAÇÃO DO ICMS
        Este registro tem por objetivo informar o(s) período(s) das apurações em separado do ICMS. Os períodos
        informados devem abranger todo o intervalo da escrituração fiscal, sem sobreposição ou omissão de datas ou períodos.
        Não podem ser informados dois ou mais registros com a mesma combinação de valores dos campos 02 (DT_INI) e
        03 (DT_FIN). Não devem existir lacunas ou sobreposições de datas nos períodos de apuração informados nestes registros,
        em comparação com as datas informadas no registro 0000.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1910, self).__init__()
            self.REG = '1910'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = '1900'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DT_INI = ''  # Data inicial da sub-apuração
            self.DT_FIN = ''  # Data final da sub-apuração
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1920(TrackedAttributesClass):
        """
        REGISTRO 1920: SUB-APURAÇÃO DO ICMS
        Este registro tem por objetivo informar os valores relativos a apurações especificadas no registro 1900, que se
        referem aos valores do ICMS das operações próprias estornados do registro E110 através de ajustes decorrentes de
        documentos, nos campos 03 (VL_AJ_DEBITOS) e 07 (VL_AJ_CREDITOS), e através de ajustes de apuração nos campos
        05 (VL_ESTORNOS_CRED) e 09 (VL_ESTORNOS_DEB).
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1920, self).__init__()
            self.REG = '1920'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = '1910'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_TOT_TRANSF_DEBITOS_OA = ''  # Valor total dos débitos por "Saídas e prestações com débito do imposto"
            self.VL_TOT_AJ_DEBITOS_OA = ''  # Valor total de "Ajustes a débito"
            self.VL_ESTORNOS_CRED_OA = ''  # Valor total de Ajustes “Estornos de créditos”
            self.VL_TOT_TRANSF_CREDITOS_OA = ''  # Valor total dos créditos por "Entradas e aquisições com crédito do imposto"
            self.VL_TOT_AJ_CREDITOS_OA = ''  # Valor total de "Ajustes a crédito"
            self.VL_ESTORNOS_DEB_OA = ''  # Valor total de Ajustes “Estornos de Débitos”
            self.VL_SLD_CREDOR_ANT_OA = ''  # Valor total de "Saldo credor do período anterior"
            self.VL_SLD_APURADO_OA = ''  # Valor do saldo devedor apurado
            self.VL_TOT_DED = ''  # Valor total de "Deduções"
            self.VL_ICMS_RECOLHER_OA = ''  # Valor total de "ICMS a recolher (09-10)
            self.VL_SLD_CREDOR_TRANSP_OA = ''  # Valor total de "Saldo credor a transportar para o período seguinte”
            self.DEB_ESP_OA = ''  # Valores recolhidos ou a recolher, extra- apuração.
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1921(TrackedAttributesClass):
        """
        REGISTRO 1921: AJUSTE/BENEFÍCIO/INCENTIVO DA SUB-APURAÇÃO DO ICMS
        Este registro tem por objetivo discriminar todos os ajustes lançados nos campos VL_TOT_AJ_DEBITOS_OA,
        VL_ESTORNOS_CRED_OA, VL_TOT_AJ_CREDITOS_OA, VL_ESTORNOS_DEB_OA, VL_TOT_DED e
        DEB_ESP_OA, todos do registro 1920.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1921, self).__init__()
            self.REG = '1921'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = '1920'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_AJ_APUR = ''  # Código do ajuste da SUB-APURAÇÃO e dedução,conforme a Tabela indicada no item 5.1.1.
            self.DESCR_COMPL_AJ = ''  # Descrição complementar do ajuste da apuração.
            self.VL_AJ_APUR = ''  # Valor do ajuste da apuração
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1922(TrackedAttributesClass):
        """
        REGISTRO 1922: INFORMAÇÕES ADICIONAIS DOS AJUSTES DA SUB-APURAÇÃO DO ICMS
        Este registro tem por objetivo detalhar os ajustes do registro 1921 quando forem relacionados a processos judiciais
        ou fiscais ou a documentos de arrecadação, observada a legislação estadual pertinente. Valores recolhidos, com influência
        nesta apuração em separado (sub-apuração) do ICMS, devem ser detalhados neste registro, com identificação do
        documento de arrecadação específico.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1922, self).__init__()
            self.REG = '1922'  # Texto fixo contendo
            self.nivel_h = 6  # nível
            self.pai = '1921'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DA = ''  # Número do documento de arrecadação estadual, se houver
            self.NUM_PROC = ''  # Número do processo ao qual o ajuste está vinculado, se houver
            self.IND_PROC = ''  # Indicador da origem do processo: 0- SEFAZ; 1- Justiça Federal; 2- Justiça Estadual; 9- Outros
            self.PROC = ''  # Descrição resumida do processo que embasou o lançamento
            self.TXT_COMPL = ''  # Descrição complementar
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1923(TrackedAttributesClass):
        """
        REGISTRO 1923: INFORMAÇÕES ADICIONAIS DOS AJUSTES DA SUB-APURAÇÃO DO ICMS – IDENTIFICAÇÃO DOS DOCUMENTOS FISCAIS
        Este registro tem por objetivo identificar os documentos fiscais relacionados ao ajuste.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1923, self).__init__()
            self.REG = '1923'  # Texto fixo contendo
            self.nivel_h = 6  # nível
            self.pai = '1921'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''  # Código do participante (campo 02 do Registro 0150): - do emitente do documento ou do remetente das mercadorias, no caso de entradas; - do adquirente, no caso de saídas
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subserie do documento fiscal
            self.NUM_DOC = ''  # Número do documento fiscal
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.VL_AJ_ITEM = ''  # Valor do ajuste para a operação/item
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1925(TrackedAttributesClass):
        """
        REGISTRO 1925: INFORMAÇÕES ADICIONAIS DA SUB-APURAÇÃO – VALORES DECLARATÓRIOS
        Este registro tem o objetivo de informar os valores declaratórios relativos ao ICMS desta apuração em separado
        (sub-apuração), conforme definição da legislação estadual pertinente. Esses valores são meramente declaratórios e não são
        computados nesta apuração em separado (sub-apuração) do ICMS.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1925, self).__init__()
            self.REG = '1925'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = '1920'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_INF_ADIC = ''  # Código da informação adicional conforme tabela a ser definida pelas SEFAZ, conforme tabela definida no item 5.2.
            self.VL_INF_ADIC = ''  # Valor referente à informação adicional
            self.DESCR_COMPL_AJ = ''  # Descrição complementar do ajuste
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1926(TrackedAttributesClass):
        """
        REGISTRO 1926: OBRIGAÇÕES DO ICMS A RECOLHER – OPERAÇÕES REFERENTES À SUB-APURAÇÃO
        Este registro tem o objetivo de discriminar os pagamentos realizados (débitos especiais) ou a realizar, referentes à
        apuração em separado (sub-apuração) do ICMS identificada no registro 1900. A soma do valor das obrigações deste
        registro deve ser igual à soma dos campos VL_ICMS_RECOLHER_OA e DEB_ESP_OA, do registro 1920.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1926, self).__init__()
            self.REG = '1926'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = '1920'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_OR = ''  # Código da obrigação a recolher, conforme a Tabela 5.4
            self.VL_OR = ''  # Valor da obrigação a recolher
            self.DT_VCTO = ''  # Data de vencimento da obrigação
            self.COD_REC = ''  # Código de receita referente à obrigação, próprio da unidade da federação, conforme legislação estadual,
            self.NUM_PROC = ''  # Número do processo ou auto de infração ao qual a obrigação está vinculada, se houver.
            self.IND_PROC = ''  # Indicador da origem do processo: 0- SEFAZ; 1- Justiça Federal; 2- Justiça Estadual; 9- Outros
            self.PROC = ''  # Descrição resumida do processo que embasou o lançamento
            self.TXT_COMPL = ''  # Descrição complementar das obrigações a recolher.
            self.MES_REF = ''  # Informe o mês de referência no formato “mmaaaa”
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_1990(TrackedAttributesClass):
        """
        REGISTRO 1990: ENCERRAMENTO DO BLOCO 1
        Este registro destina-se a identificar o encerramento do Bloco 1 e a informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1990, self).__init__()
            self.REG = '1990'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN_1 = ''  # Quantidade total de linhas do Bloco 1
            self.fieldnames = ('REG', 'QTD_LIN_1')
            self.formato = self.get_formato()
