# -*- coding: utf-8 -*-

from ..utils import *


class bloco_9(TrackedAttributesClass):
    """
    BLOCO 9: CONTROLE E ENCERRAMENTO DO ARQUIVO DIGITAL
    Este bloco representa os totais de registros e serve como forma de controle para batimentos e verificações.
    """

    class registro_9001(TrackedAttributesClass):
        """
        REGISTRO 9001: ABERTURA DO BLOCO 9
        Este registro deve sempre ser gerado e representa a abertura do Bloco 9.
        """

        _order = []

        def __init__(self):
            super(bloco_9.registro_9001, self).__init__()
            self.REG = '9001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = '0'  # Indicador de movimento:0- Bloco com dados informados; 1- Bloco sem dados informados.
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_9900(TrackedAttributesClass):
        """
        REGISTRO 9900: REGISTROS DO ARQUIVO.
        Todos os registros referenciados neste arquivo, inclusive os posteriores a este registro, devem ter uma linha
        totalizadora do seu número de ocorrências.
        """
        _order = []

        def __init__(self):
            super(bloco_9.registro_9900, self).__init__()
            self.REG = '9900'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = '9001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.REG_BLC = ''  # Registro que será totalizado no próximo campo.
            self.QTD_REG_BLC = ''  # Total de registros do tipo informado no campo anterior.
            self.fieldnames = ('REG', 'REG_BLC', 'QTD_REG_BLC')
            self.formato = self.get_formato()

    class registro_9990(TrackedAttributesClass):
        """
        REGISTRO 9990: ENCERRAMENTO DO BLOCO 9
        Este registro destina-se a identificar o encerramento do Bloco 9 e a informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_9.registro_9990, self).__init__()
            self.REG = '9990'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN_9 = ''  # Quantidade total de linhas do Bloco 9.
            self.fieldnames = ('REG', 'QTD_LIN_9')
            self.formato = self.get_formato()

    class registro_9999(TrackedAttributesClass):
        """
        REGISTRO 9999: ENCERRAMENTO DO ARQUIVO DIGITAL.
        Este registro destina-se a identificar o encerramento do arquivo digital e a informar a quantidade de linhas
        (registros) existentes no arquivo
        """
        _order = []

        def __init__(self):
            super(bloco_9.registro_9999, self).__init__()
            self.REG = '9999'
            self.nivel_h = 0  # nível hierárquico
            self.pai = ''  # fechamento do arquivo
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN = ''  #Quantidade total de linhas do arquivo digital.
            self.fieldnames = ('REG', 'QTD_LIN')
            self.formato = self.get_formato()
