# -*- coding: utf-8 -*-

from ..utils import *


class bloco_c(TrackedAttributesClass):
    """
    BLOCO C: DOCUMENTOS FISCAIS I - MERCADORIAS (ICMS/IPI)
    """

    class registro_C001(TrackedAttributesClass):
        """
        REGISTRO C001: ABERTURA DO BLOCO C
        Este registro tem por objetivo identificar a abertura do bloco C, indicando se há informações sobre documentos
        fiscais.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C001, self).__init__()
            self.REG = 'C001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = '0'  # Indicador de movimento:0- Bloco com dados informados;1- Bloco sem dados informados.
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_C100(TrackedAttributesClass):
        """
        REGISTRO C100: NOTA FISCAL (CÓDIGO 01), NOTA FISCAL AVULSA (CÓDIGO
        1B), NOTA FISCAL DE PRODUTOR (CÓDIGO 04) E NF-e (CÓDIGO 55).
        Este registro deve ser gerado para cada documento fiscal código 01, 1B, 04 e 55, conforme item 4.1.1 do Ato
        COTEPE/ICMS no 09, de 18 de abril de 2008, registrando a entrada ou saída de produtos ou outras situações que envolvam
        a emissão dos documentos fiscais mencionado
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C100, self).__init__()
            self.REG = 'C100'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''  # Indicador do tipo de operação:   0- Entrada;   1- Saída
            self.IND_EMIT = ''  # Indicador do emitente do documento fiscal: 0- Emissão própria; 1- Terceiros
            self.COD_PART = ''  # Código do participante (campo 02 do Registro  0150):  - do emitente do documento ou do remetente das ercadorias, no caso de entradas; - do adquirente, no caso de saídas
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''  # Código da situação do documento fiscal,  conforme a Tabela 4.1.2
            self.SER = ''  # Série do documento fiscal
            self.NUM_DOC = ''  # Número do documento fiscal
            self.CHV_NFE = ''  # Chave da Nota Fiscal Eletrônica
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.DT_E_S = ''  # Data da entrada ou da saída
            self.VL_DOC = ''  # Valor total do documento fiscal
            self.IND_PGTO = ''  # Indicador do tipo de pagamento:  0- À vista;   1- A prazo;  9- Sem pagamento.
            self.VL_DESC = ''  # Valor total do desconto
            self.VL_ABAT_NT = ''  # Abatimento não tributado e não comercial Ex.desconto ICMS nas remessas para ZFM.
            self.VL_MERC = ''  # Valor total das mercadorias e serviços
            self.IND_FRT = ''  # Indicador do tipo do frete:  0- Por conta do emitente; 1- Por conta do destinatário/remetente;  2- Por conta de terceiros;  9- Sem cobrança de frete.
            self.VL_FRT = ''  # Valor do frete indicado no documento fiscal
            self.VL_SEG = ''  # Valor do seguro indicado no documento fiscal
            self.VL_OUT_DA = ''  # Valor de outras despesas acessórias
            self.VL_BC_ICMS = ''  # Valor da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor do ICMS
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor do ICMS retido por substituição tributária
            self.VL_IPI = ''  # Valor total do IPI
            self.VL_PIS = ''  # Valor total do PIS
            self.VL_COFINS = ''  # Valor total da COFINS
            self.VL_PIS_ST = ''  # Valor total do PIS retido por substituição tributária
            self.VL_COFINS_ST = ''  # Valor total da COFINS retido por substituição tributária
            self.registro_C110 = []
            self.registro_C170 = []
            self.registro_C190 = []
            self.registro_C195 = []
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'NUM_DOC', 'CHV_NFE', 'DT_DOC', 'DT_E_S', 'VL_DOC',
                               'IND_PGTO', 'VL_DESC', 'VL_ABAT_NT', 'VL_MERC', 'IND_FRT', 'VL_FRT',
                               'VL_SEG', 'VL_OUT_DA', 'VL_BC_ICMS', 'VL_ICMS', 'VL_BC_ICMS_ST',
                               'VL_ICMS_ST', 'VL_IPI', 'VL_PIS', 'VL_COFINS', 'VL_PIS_ST',
                               'VL_COFINS_ST')
            self.formato = self.get_formato()

    class registro_C101(TrackedAttributesClass):
        """
        REGISTRO C101: INFORMAÇÃO COMPLEMENTAR DOS DOCUMENTOS
        FISCAIS QUANDO DAS OPERAÇÕES INTERESTADUAIS DESTINADAS A
        CONSUMIDOR FINAL NÃO CONTRIBUINTE EC 87/15 (CÓDIGO 55)
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C101, self).__init__()
            self.REG = 'C101'
            self.nivel_h = 3
            self.pai = 'C100'
            self.ocorrencia = '1'
            self.VL_FCP_UF_DEST = ''
            self.VL_ICMS_UF_DEST = ''
            self.VL_ICMS_UF_REM = ''
            self.fieldnames = ('REG', 'VL_FCP_UF_DEST', 'VL_ICMS_UF_DEST', 'VL_ICMS_UF_REM')
            self.formato = self.get_formato()

    class registro_C105(TrackedAttributesClass):
        """
        REGISTRO C105 – OPERAÇÕES COM ICMS ST RECOLHIDO PARA UF DIVERSA
        DO DESTINATÁRIO DO DOCUMENTO FISCAL (CÓDIGO 55).
        Este registro tem por objetivo identificar a UF destinatária do recolhimento do ICMS ST, quando esta for diversa
        da UF do destinatário do produto. Ex. Leasing de veículo quando a entidade financeira está localizada em uma UF e o
        destinatário do produto em outra UF.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C105, self).__init__()
            self.REG = 'C105'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.OPER = ''  # Indicador do tipo de operação:0- Combustíveis e Lubrificantes;1- leasing de veículos ou faturamento direto.
            self.UF = ''  # Sigla da UF de destino do ICMS_ST
            self.fieldnames = ('REG', 'OPER', 'UF')
            self.formato = self.get_formato()

    class registro_C110(TrackedAttributesClass):
        """
        REGISTRO C110: INFORMAÇÃO COMPLEMENTAR DA NOTA FISCAL (CÓDIGO 01, 1B, 04 e 55).
        Este registro tem por objetivo identificar os dados contidos no campo Informações Complementares da Nota
        Fiscal, que sejam de interesse do fisco, conforme dispõe a legislação. Devem ser discriminados em registros “filhos
        próprios” as informações relacionadas com documentos fiscais, processos, cupons fiscais, documentos de arrecadação e
        locais de entrega ou coleta que foram explicitamente citadas no campo “Informações Complementares” da Nota Fiscal.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo conteúdo no
        campo COD_INF.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C110, self).__init__()
            self.REG = 'C110'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_INF = ''  # Código da informação complementar do documento fiscal (campo 02 do Registro 0450)
            self.TXT_COMPL = ''  # Descrição complementar do código de referência.
            self.fieldnames = ('REG', 'COD_INF', 'TXT_COMPL')
            self.formato = self.get_formato()

    class registro_C111(TrackedAttributesClass):
        """
        REGISTRO C111: PROCESSO REFERENCIADO
        Este registro deve ser apresentado, obrigatoriamente, quando no campo – “Informações Complementares” da nota
        fiscal - constar a discriminação de processos referenciados no documento fiscal.
        Não podem ser informados dois ou mais registros com o mesmo conteúdo no campo NUM_PROC para um
        mesmo registro C110.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C111, self).__init__()
            self.REG = 'C111'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_PROC = ''  # Identificação do processo ou ato concessório.
            self.IND_PROC = ''  # Indicador da origem do processo:0 - SEFAZ; 1 - Justiça Federal; 2 - Justiça Estadual; 3 - SECEX/SRF 9 - Outros.
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_C112(TrackedAttributesClass):
        """
        REGISTRO C112: DOCUMENTO DE ARRECADAÇÃO REFERENCIADO.
        Este registro deve ser apresentado, obrigatoriamente, quando no campo – “Informações Complementares” da
        nota fiscal - constar a identificação de um documento de arrecadação.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C112, self).__init__()
            self.REG = 'C112'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_DA = ''  # Código do modelo do documento de arrecadação :0 - documento estadual de arrecadação 1 – GNRE
            self.UF = ''  # Unidade federada beneficiária do recolhimento
            self.NUM_DA = ''  # Número do documento de arrecadação
            self.COD_AUT = ''  # Código completo da autenticação bancária
            self.VL_DA = ''  # Valor do total do documento de arrecadação (principal, atualização monetária, juros e multa)
            self.DT_VCTO = ''  # Data de vencimento do documento de arrecadação
            self.DT_PGTO = ''  # Data de pagamento do documento de arrecadação, ou data do vencimento, no caso de ICMS antecipado a recolher
            self.fieldnames = ('REG', 'COD_DA', 'UF', 'NUM_DA', 'COD_AUT', 'VL_DA', 'DT_VCTO',
                               'DT_PGTO')
            self.formato = self.get_formato()

    class registro_C113(TrackedAttributesClass):
        """
        REGISTRO C113: DOCUMENTO FISCAL REFERENCIADO.
        Este registro tem por objetivo informar, detalhadamente, outros documentos fiscais que tenham sido mencionados
        nas informações complementares do documento que está sendo escriturado no registro C100, exceto cupons fiscais, que
        devem ser informados no registro C114.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C113, self).__init__()
            self.REG = 'C113'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''  # Indicador do tipo de operação: 0- Entrada/aquisição; 1- Saída/prestação
            self.IND_EMIT = ''  # Indicador do emitente do título: 0- Emissão própria; 1- Terceiros
            self.COD_PART = ''  # Código do participante emitente (campo 02 do Registro 0150) do documento referenciado.
            self.COD_MOD = ''  # Código do documento fiscal, conforme a Tabela 4.1.1
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subsérie do documento fiscal
            self.NUM_DOC = ''  # Número do documento fiscal
            self.DT_DOC = ''  # Data da emissão do documento fiscal.
            self.CHV_DOCe = ''  # Chave do Documento Eletronico
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'SER', 'SUB',
                               'NUM_DOC', 'DT_DOC', 'CHV_DOCe')
            self.formato = self.get_formato()

    class registro_C114(TrackedAttributesClass):
        """
        REGISTRO C114: CUPOM FISCAL REFERENCIADO.
        Este registro será utilizado para informar, detalhadamente, nas operações de saídas, cupons fiscais que tenham sido
        mencionados nas informações complementares do documento que está sendo escriturado no registro C100. Nas operações
        de entradas, somente informar quando o emitente do cupom fiscal for o próprio informante do arquivo. Não podem ser
        informados para um mesmo documento fiscal, dois ou mais registros com a mesma combinação de conteúdo nos campos
        ECF_FAB, NUM_DOC e DT_DOC.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C114, self).__init__()
            self.REG = 'C114'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a tabela indicada no item 4.1.1
            self.ECF_FAB = ''  # Número de série de fabricação do ECF
            self.ECF_CX = ''  # Número do caixa atribuído ao ECF
            self.NUM_DOC = ''  # Número do documento fiscal
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.fieldnames = ('REG', 'COD_MOD', 'ECF_FAB', 'ECF_CX', 'NUM_DOC', 'DT_DOC')
            self.formato = self.get_formato()

    class registro_C115(TrackedAttributesClass):
        """
        REGISTRO C115: LOCAL DA COLETA E/OU ENTREGA (CÓDIGO 01, 1B E 04).
        Este registro tem por objetivo informar o local de coleta, quando este for diferente do endereço do emitente do
        documento fiscal e/ou local de entrega, quando este for diferente do endereço do destinatário do documento fiscal, além de
        informar a modalidade de transporte utilizada. As informações prestadas referem-se a transporte próprio ou de terceiros.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C115, self).__init__()
            self.REG = 'C115'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.ND_CARGA = ''  # Indicador do tipo de transporte:0 – Rodoviário; 1 – Ferroviário; 2 – Rodo-Ferroviário;3 – Aquaviário; 4 – Dutoviário; 5 – Aéreo; 9 – Outros.
            self.CNPJ_COL = ''  # Número do CNPJ do contribuinte do local de coleta
            self.IE_COL = ''  # Inscrição Estadual do contribuinte do local de  coleta
            self.CPF_COL = ''  # CPF do contribuinte do local de coleta das mercadorias
            self.COD_MUN_COL = ''  # Código do Município do local de coleta
            self.CNPJ_ENTG = ''  # Número do CNPJ do contribuinte do local de entrega
            self.IE_ENTG = ''  # Inscrição Estadual do contribuinte do local de entrega
            self.CPF_ENTG = ''  # Cpf do contribuinte do local de entrega
            self.COD_MUN_ENTG = ''  # Código do Município do local de entrega
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C116(TrackedAttributesClass):
        """
        REGISTRO C116: CUPOM FISCAL ELETRÔNICO REFERENCIADO
        Este registro será utilizado para informar, detalhadamente, nas operações de saídas, cupons
        fiscais eletrônicos que tenham sido mencionados nas informações complementares do documento que está
        sendo escriturado no registro C100. Nas operações de entradas no registro C100, somente informar quando o
        emitente do cupom fiscal for o próprio informante do arquivo. Não podem ser informados para um mesmo
        documento fiscal, dois ou mais registros com a mesma combinação de conteúdo nos campos NR_SAT,
        NUM_CFE e DT_DOC.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C116, self).__init__()
            self.REG = 'C116'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.NR_SAT = ''  # Número de Série do equipamento SAT
            self.CHV_CFE = ''  # Chave do Cupom Fiscal Eletrônico
            self.NUM_CFE = ''  # Número do cupom fiscal eletrônico
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C120(TrackedAttributesClass):
        """
        REGISTRO C120: OPERAÇÕES DE IMPORTAÇÃO (CÓDIGO 01).
        Este registro tem por objetivo informar detalhes das operações de importação, que estejam sendo documentadas
        pela nota fiscal escriturada no registro C100, quando o campo IND_OPER for igual a “0” (zero), indicando operação de
        entrada.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo conteúdo no
        campo NUM_DOC__IMP e NUM_ACDRAW.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C120, self).__init__()
            self.REG = 'C120'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_DOC_IMP = ''  # Documento de importação: 0 – Declaração de Importação; 1 – Declaração Simplificada de Importação.
            self.NUM_DOC__IMP = ''  # Número do documento de Importação.
            self.PIS_IMP = ''  # Valor pago de PIS na importação
            self.COFINS_IMP = ''  # Valor pago de COFINS na importação
            self.NUM_ACDRAW = ''  # Número do Ato Concessório do regime Drawback
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C130(TrackedAttributesClass):
        """
        REGISTRO C130: ISSQN, IRRF E PREVIDÊNCIA SOCIAL.
        Este registro tem por objetivo informar dados da prestação de serviços sob não-incidência ou não tributados pelo
        ICMS e ainda detalhes sobre a retenção de Imposto de Renda Retido na Fonte (IRRF) e de contribuições previdenciárias.
        Essas três situações possuem características próprias e tratamentos específicos na legislação, não guardando entre elas
        nenhuma relação.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C130, self).__init__()
            self.REG = 'C130'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_SERV_NT = ''  # Valor dos serviços sob não-incidência ou não- tributados pelo ICMS
            self.VL_BC_ISSQN = ''  # Valor da base de cálculo do ISSQN
            self.VL_ISSQN = ''  # Valor do ISSQN
            self.VL_BC_IRRF = ''  # Valor da base de cálculo do Imposto de Renda Retido na Fonte
            self.VL_IRRF = ''  # Valor do Imposto de Renda - Retido na Fonte
            self.VL_BC_PREV = ''  # Valor da base de cálculo de retenção da Previdência Social
            self.VL_PREV = ''  # Valor destacado para retenção da Previdência Social
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C140(TrackedAttributesClass):
        """
        REGISTRO C140: FATURA (CÓDIGO 01)
        Este registro tem por objetivo informar dados da fatura comercial, sempre que a aquisição ou venda de
        mercadorias for a prazo, através de notas fiscais modelo 1 ou 1A. Devem ser consideradas as informações quando da
        emissão do documento fiscal, incluindo a parcela paga no ato da operação, se for o caso.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C140, self).__init__()
            self.REG = 'C140'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_EMIT = ''  # Indicador do emitente do título:0- Emissão própria; 1- Terceiros
            self.IND_TIT = ''  # Indicador do tipo de título de crédito: 00- Duplicata; 01- Cheque; 02- Promissória; 03- Recibo; 99- Outros (descrever)
            self.DESC_TIT = ''  # Descrição complementar do título de crédito
            self.NUM_TIT = ''  # Número ou código identificador do título de crédito
            self.QTD_PARC = ''  # Quantidade de parcelas a receber/pagar
            self.VL_TIT = ''  # Valor total dos títulos de créditos
            self.fieldnames = ('REG', 'IND_EMIT', 'IND_TIT', 'DESC_TIT', 'NUM_TIT', 'QTD_PARC',
                               'VL_TIT')
            self.formato = self.get_formato()

    class registro_C141(TrackedAttributesClass):
        """
        REGISTRO C141: VENCIMENTO DA FATURA (CÓDIGO 01).
        Este registro deve ser apresentado, obrigatoriamente, sempre que for informado o registro C140, devendo ser
        discriminados o valor e a data de vencimento de cada uma das parcelas.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C141, self).__init__()
            self.REG = 'C141'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C140'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_PARC = ''  # Número da parcela a receber/pagar
            self.DT_VCTO = ''  # Data de vencimento da parcela
            self.VL_PARC = ''  # Valor da parcela a receber/pagar
            self.fieldnames = ('REG', 'NUM_PARC', 'DT_VCTO', 'VL_PARC')
            self.formato = self.get_formato()

    class registro_C160(TrackedAttributesClass):
        """
        REGISTRO C160: VOLUMES TRANSPORTADOS (CÓDIGO 01 E 04) - EXCETO COMBUSTÍVEIS.
        Este registro tem por objetivo informar detalhes dos volumes, do transportador e do veículo empregado no
        transporte nas operações de saídas.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C160, self).__init__()
            self.REG = 'C160'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_PART = ''  # Código do participante (campo 02 do Registro 0150): - transportador, se houver
            self.VEIC_ID = ''  # Placa de identificação do veículo automotor
            self.QTD_VOL = ''  # Quantidade de volumes transportados
            self.PESO_BRT = ''  # Peso bruto dos volumes transportados (em Kg)
            self.PESO_LIQ = ''  # Peso líquido dos volumes transportados (em Kg)
            self.UF_ID = ''  # Sigla da UF da placa do veículo
            self.fieldnames = ('REG', 'COD_PART', 'VEIC_ID', 'QTD_VOL', 'PESO_BRT', 'PESO_LIQ',
                               'UF_ID')
            self.formato = self.get_formato()

    class registro_C165(TrackedAttributesClass):
        """
        REGISTRO C165: OPERAÇÕES COM COMBUSTÍVEIS (CÓDIGO 01).
        Este registro deve ser apresentado pelas empresas do segmento de combustíveis (distribuidoras, refinarias,
        revendedoras) em operações de saída. Postos de combustíveis não devem apresentar este registro. Não podem ser
        informados para um mesmo documento fiscal, dois ou mais registros com a mesma combinação de conteúdo nos campos
        COD_PART e VEIC_ID.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C165, self).__init__()
            self.REG = 'C165'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''  # Código do participante (campo 02 do Registro 0150): - transportador, se houver
            self.VEIC_ID = ''  # Placa de identificação do veículo
            self.COD_AUT = ''  # Código da autorização fornecido pela SEFAZ (combustíveis)
            self.NR_PASSE = ''  # Número do Passe Fiscal
            self.HORA = ''  # Hora da saída das mercadorias
            self.TEMPER = ''  # Temperatura em graus Celsius utilizada para quantificação do volume de combustível
            self.QTD_VOL = ''  # Quantidade de volumes transportados
            self.PESO_BRT = ''  # Peso bruto dos volumes transportados (em Kg)
            self.PESO_LIQ = ''  # Peso líquido dos volumes transportados (em Kg)
            self.NOM_MOT = ''  # Nome do motorista
            self.CPF = ''  # CPF do motorista
            self.UF_ID = ''  # Sigla da UF da placa do veículo
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C170(TrackedAttributesClass):
        """
        REGISTRO C170: ITENS DO DOCUMENTO (CÓDIGO 01, 1B, 04 e 55).
        Registro obrigatório para discriminar os itens da nota fiscal (mercadorias e/ou serviços constantes em notas
        conjugadas), inclusive em operações de entrada de mercadorias acompanhada de Nota Fiscal Eletrônica (NF-e) de emissão
        de terceiros.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C170, self).__init__()
            self.REG = 'C170'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''  # Número sequencial do item no documento fiscal
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.DESCR_COMPL = ''  # Descrição complementar do item como adotado no documento fiscal
            self.QTD = ''  # Quantidade do item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor total do item (mercadorias ou serviços)
            self.VL_DESC = ''  # Valor do desconto comercial
            self.IND_MOV = ''  # Movimentação física do ITEM/PRODUTO:0. SIM 1. NÃO
            self.CST_ICMS = ''  # Código da Situação Tributária referente ao ICMS, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.COD_NAT = ''  # Código da natureza da operação (campo 02 do Registro 0400)
            self.VL_BC_ICMS = ''  # Valor da base de cálculo do ICMS
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_ICMS = ''  # Valor do ICMS creditado/debitado
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo referente à substituição tributária
            self.ALIQ_ST = ''  # Alíquota do ICMS da substituição tributária na unidade da federação de destino
            self.VL_ICMS_ST = ''  # Valor do ICMS referente à substituição tributária
            self.IND_APUR = ''  # Indicador de período de apuração do IPI: 0 - Mensal; 1 - Decendial
            self.CST_IPI = ''  # Código da Situação Tributária referente ao IPI, conforme a Tabela indicada no item 4.3.2.
            self.COD_ENQ = ''  # Código de enquadramento legal do IPI, conforme tabela indicada no item 4.5.3.
            self.VL_BC_IPI = ''  # Valor da base de cálculo do IPI
            self.ALIQ_IPI = ''  # Alíquota do IPI
            self.VL_IPI = ''  # Valor do IPI creditado/debitado
            self.CST_PIS = ''  # Código da Situação Tributária referente ao PIS.
            self.VL_BC_PIS = ''  # Valor da base de cálculo do PIS
            self.ALIQ_PIS = ''  # Alíquota do PIS (em percentual)
            self.QUANT_BC_PIS = ''  # Quantidade – Base de cálculo PIS
            self.ALIQ_PIS_REAIS = ''  # Alíquota do PIS (em reais)
            self.VL_PIS = ''  # Valor do PIS
            self.CST_COFINS = ''  # Código da Situação Tributária referente ao COFINS.
            self.VL_BC_COFINS = ''  # Valor da base de cálculo da COFINS
            self.ALIQ_COFINS = ''  # Alíquota do COFINS (em percentual)
            self.QUANT_BC_COFINS = ''  # Quantidade – Base de cálculo COFINS
            self.ALIQ_COFINS_REAIS = ''  # Alíquota da COFINS (em reais)
            self.VL_COFINS = ''  # Valor da COFINS
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'DESCR_COMPL', 'QTD', 'UNID',
                               'VL_ITEM', 'VL_DESC', 'IND_MOV', 'CST_ICMS', 'CFOP', 'COD_NAT',
                               'VL_BC_ICMS', 'ALIQ_ICMS', 'VL_ICMS', 'VL_BC_ICMS_ST', 'ALIQ_ST',
                               'VL_ICMS_ST', 'IND_APUR', 'CST_IPI', 'COD_ENQ', 'VL_BC_IPI',
                               'ALIQ_IPI', 'VL_IPI', 'CST_PIS', 'VL_BC_PIS', 'ALIQ_PIS',
                               'QUANT_BC_PIS', 'ALIQ_PIS_REAIS', 'VL_PIS', 'CST_COFINS',
                               'VL_BC_COFINS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_REAIS', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C171(TrackedAttributesClass):
        """
        REGISTRO C171: ARMAZENAMENTO DE COMBUSTIVEIS (código 01, 55).
        Este registro deve ser apresentado pelas empresas do comércio varejista de combustíveis, somente nas operações
        de entrada, para informar o volume recebido (em litros), por item do documento fiscal, conforme Livro de Movimentação
        de Combustíveis (LMC), Ajuste SINIEF 01/92.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo conteúdo no
        campo NUM_TANQUE.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C171, self).__init__()
            self.REG = 'C171'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_TANQUE = ''  # Tanque onde foi armazenado o combustível
            self.QTDE = ''  # Quantidade ou volume armazenado
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C172(TrackedAttributesClass):
        """
        REGISTRO C172: OPERAÇÕES COM ISSQN (CÓDIGO 01)
        Este registro tem por objetivo informar dados da prestação de serviços.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C172, self).__init__()
            self.REG = 'C172'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_BC_ISSQN = ''  # Valor da base de cálculo do ISSQN
            self.ALIQ_ISSQN = ''  # Alíquota do ISSQN
            self.VL_ISSQN = ''  # Valor do ISSQN
            self.fieldnames = ('REG', 'VL_BC_ISSQN', 'ALIQ_ISSQN', 'VL_ISSQN')
            self.formato = self.get_formato()

    class registro_C173(TrackedAttributesClass):
        """
        REGISTRO C173: OPERAÇÕES COM MEDICAMENTOS (CÓDIGO 01 e 55).
        Este registro deve ser apresentado pelas empresas do segmento farmacêutico (distribuidoras, indústrias,
        revendedoras e importadoras), exceto comércio varejista.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C173, self).__init__()
            self.REG = 'C173'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.LOTE_MED = ''  # Número do lote de fabricação do medicamento
            self.QTD_ITEM = ''  # Quantidade de item por lote
            self.DT_FAB = ''  # Data de fabricação do medicamento
            self.DT_VAL = ''  # Data de expiração da validade do medicamento
            self.IND_MED = ''  # Indicador de tipo de referência da base de cálculo do ICMS (ST) do produto farmacêutico: 0- Base de cálculo referente ao preço tabelado ou preço máximo sugerido; 1- Base cálculo – Margem de valor agregado; 2- Base de cálculo referente à Lista Negativa; 3- Base de cálculo referente à Lista Positiva; 4- Base de cálculo referente à Lista Neutra
            self.TP_PROD = ''  # Tipo de produto: 0- Similar; 1- Genérico; 2- Ético ou de marca;
            self.VL_TAB_MAX = ''  # Valor do preço tabelado ou valor do preço máximo
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C174(TrackedAttributesClass):
        """
        REGISTRO C174: OPERAÇÕES COM ARMAS DE FOGO (CÓDIGO 01).
        Este registro deve ser apresentado pelas empresas que realizam operações com armas de fogo (indústria, comércio
        e demais) e deve ser fornecido apenas para operações de saída.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo valor do
        campo NUM_ARM.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C174, self).__init__()
            self.REG = 'C174'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_ARM  # Indicador do tipo da arma de fogo:0- Uso permitido; 1- Uso restrito
            self.NUM_ARM  # Numeração de série de fabricação da arma
            self.DESCR_COMPL  # Descrição da arma, compreendendo: número do cano, calibre, marca, capacidade de cartuchos, tipo de funcionamento, quantidade de canos, comprimento, tipo de arma, quantidade e sentido das raias e demais elementos que permitam sua perfeita identificação
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C175(TrackedAttributesClass):
        """
        REGISTRO C175: OPERAÇÕES COM VEÍCULOS NOVOS (CÓDIGO 01 e 55).
        Este registro deve ser apresentado pelas empresas do segmento automotivo (montadoras-capítulo 87 da NCM,
        concessionárias e importadoras) para informar os itens relativos aos veículos novos. Deve ser informado nas operações de
        entrada e saída (exceto pelos contribuintes emissores de NF-e), exceto quando se tratar de operações de exportação.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C175, self).__init__()
            self.REG = 'C175'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_VEIC_OPER = ''  # Indicador do tipo de operação com veículo: 0- Venda para concessionária; 1- Faturamento direto; 2- Venda direta; 3- Venda da concessionária; 9- Outros
            self.CNPJ = ''  # CNPJ da Concessionária
            self.UF = ''  # Sigla da unidade da federação da Concessionária
            self.CHASSI_VEIC = ''  # Chassi do veículo
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C176(TrackedAttributesClass):
        """
        REGISTRO C176: RESSARCIMENTO DE ICMS EM OPERAÇÕES COM SUBSTITUIÇÃO TRIBUTÁRIA (CÓDIGO 01, 55).
        Este registro deve ser informado quando da emissão de documento fiscal, destinado a outra unidade federada, que
        ensejará futuro pedido de ressarcimento de ICMS, em operações com produtos submetidos à substituição tributária na
        operação anterior. Aplica-se somente aos contribuintes domiciliados nos estados, cuja legislação obriga a emissão de nota
        fiscal para documentar processo de pedido de ressarcimento de ICMS/ST.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C176, self).__init__()
            self.REG = 'C176'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD_ULT_E = ''  # Código do modelo do documento fiscal relativa a última entrada
            self.NUM_DOC_ULT_E = ''  # Número do documento fiscal relativa a última entrada
            self.SER_ULT_E = ''  # Série do documento fiscal relativa a última entrada
            self.DT_ULT_E = ''  # Data relativa a última entrada da mercadoria
            self.COD_PART_ULT_E = ''  # Código do participante (do emitente do documento relativa a última entrada)
            self.QUANT_ULT_E = ''  # Quantidade do item relativa a última entrada
            self.VL_UNIT_ULT_E = ''  # Valor unitário da mercadoria constante na NF relativa a última entrada inclusive despesas acessórias.
            self.VL_UNIT_BC_ST = ''  # Valor unitário da base de cálculo do imposto pago por substituição.
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C177(TrackedAttributesClass):
        """
        REGISTRO C177: OPERAÇÕES COM PRODUTOS SUJEITOS A SELO DE CONTROLE IPI.
        Este registro tem por objetivo informar o tipo e a quantidade de selo de controle utilizada na saída dos produtos
        sujeitos ao selo de controle, pelos fabricantes ou importadores desses produtos. Ex. bebidas quentes, cigarros e relógios. Se
        o produto vendido está sujeito à selagem, o registro é obrigatório. O registro não deve ser informado nas operações de
        aquisição de produtos.
        Não apresentar na entrada.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C177, self).__init__()
            self.REG = 'C177'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_SELO_IPI = ''  # Código do selo de controle do IPI, conforme Tabela 4.5.2
            self.QT_SELO_IPI = ''  # Quantidade de selo de controle do IPI aplicada
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C178(TrackedAttributesClass):
        """
        REGISTRO C178: OPERAÇÕES COM PRODUTOS SUJEITOS À TRIBUTAÇÀO DE IPI POR UNIDADE OU QUANTIDADE DE PRODUTO.
        O registro tem por objetivo fornecer informações adicionais sobre os produtos cuja forma de tributação do IPI,
        fixada em reais, seja calculada por unidade ou por determinada quantidade de produto, conforme tabelas de classes de
        valores.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C178, self).__init__()
            self.REG = 'C178'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.CL_ENQ = ''  # Código da classe de enquadramento do IPI, conforme Tabela 4.5.1.
            self.VL_UNID = ''  # Valor por unidade padrão de tributação
            self.QUANT_PAD = ''  # Quantidade total de produtos na unidade padrão de tributação
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C179(TrackedAttributesClass):
        """
        REGISTRO C179: INFORMAÇÕES COMPLEMENTARES ST (CÓDIGO 01).
        Este registro tem por objetivo informar operações que envolvam repasse, dedução e complemento de ICMS_ST nas
        operações interestaduais e nas operações com substituído intermediário.
        Não apresentar na Entrada.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C179, self).__init__()
            self.REG = 'C179'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C170'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.BC_ST_ORIG_DEST = ''  # Valor da base de cálculo ST na origem/destino em operações interestaduais.
            self.ICMS_ST_REP = ''  # Valor do ICMS-ST a repassar/deduzir em operações interestaduais
            self.ICMS_ST_COMPL = ''  # Valor do ICMS-ST a complementar à UF de destino
            self.BC_RET = ''  # Valor da BC de retenção em remessa promovida por Substituído intermediário
            self.ICMS_RET = ''  # Valor da parcela do imposto retido em remessa promovida por substituído intermediário
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C190(TrackedAttributesClass):
        """
        REGISTRO C190: REGISTRO ANALÍTICO DO DOCUMENTO (CÓDIGO 01, 1B, 04 E 55).
        Este registro tem por objetivo representar a escrituração dos documentos fiscais totalizados por CST, CFOP e
        Alíquota de ICMS.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C190, self).__init__()
            self.REG = 'C190'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação do agrupamento de itens
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor da operação na combinação de CST_ICMS, CFOP e alíquota do ICMS, correspondente ao somatório do valor das mercadorias, despesas acessórias (frete, seguros e outras despesas acessórias), ICMS_ST e IPI.
            self.VL_BC_ICMS = ''  # Parcela correspondente ao "Valor da base de cálculo do ICMS" referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_ICMS = ''  # Parcela correspondente ao "Valor do ICMS" referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_BC_ICMS_ST = ''  # Parcela correspondente ao "Valor da base de cálculo do ICMS" da substituição tributária referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_ICMS_ST = ''  # Parcela correspondente ao valor creditado/debitado do ICMS da substituição tributária, referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_RED_BC = ''  # Valor não tributado em função da redução da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_IPI = ''  # Parcela correspondente ao "Valor do IPI" referente à combinação CST_ICMS, CFOP e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal
            self.fieldnames = ('REG', 'CST_ICMS', 'CFOP', 'ALIQ_ICMS', 'VL_OPR', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_BC_ICMS_ST', 'VL_ICMS_ST', 'VL_RED_BC', 'VL_IPI',
                               'COD_OBS')
            self.formato = self.get_formato()

    class registro_C195(TrackedAttributesClass):
        """
        REGISTRO C195: OBSERVAÇOES DO LANÇAMENTO FISCAL (CÓDIGO 01, 1B E 55)
        Este registro deve ser informado quando, em decorrência da legislação estadual, houver ajustes nos documentos
        fiscais, informações sobre diferencial de alíquota, antecipação de imposto e outras situações.
        Estas informações equivalem às observações que são lançadas na coluna “Observações” dos Livros Fiscais
        previstos no Convênio SN/70 – SINIEF, art. 63, I a IV.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C195, self).__init__()
            self.REG = 'C195'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.TXT_COMPL = ''  # Descrição complementar do código de observação.
            self.fieldnames = ('REG', 'COD_OBS', 'TXT_COMPL')
            self.formato = self.get_formato()

    class registro_C197(TrackedAttributesClass):
        """
        REGISTRO C197: OUTRAS OBRIGAÇÕES TRIBUTÁRIAS, AJUSTES E INFORMAÇÕES DE VALORES PROVENIENTES DE DOCUMENTO FISCAL.
        Este registro tem por objetivo detalhar outras obrigações tributárias, ajustes e informações de valores do
        documento fiscal do registro C195, que podem ou não alterar o cálculo do valor do imposto.
        Os valores de ICMS ou ICMS ST (campo 07-VL_ICMS) serão somados diretamente na apuração, no registro
        E110, campo VL_AJ_DEBITOS ou campo VL_AJ_CREDITOS, e no registro E210, campo VL_AJ_CREDITOS_ST e
        campo VL_AJ_DEBITOS_ST, de acordo com a especificação do TERCEIRO CARACTERE do Código do Ajuste (Tabela
        5.3 do Ato COTEPE/ICMS no 09, de 18 de abril de 2008).
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C197, self).__init__()
            self.REG = 'C197'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C195'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_AJ = ''  # Código do ajustes/benefício/incentivo, conforme tabela indicada no item 5.3.
            self.DESCR_COMPL_AJ = ''  # Descrição complementar do ajuste da apuração
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.VL_BC_ICMS = ''  # Base de cálculo do ICMS ou do ICMS ST
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_ICMS = ''  # Valor do ICMS ou do ICMS ST
            self.VL_OUTROS = ''  # Outros valores
            self.fieldnames = ('REG', 'COD_AJ', 'DESCR_COMPL_AJ', 'COD_ITEM', 'VL_BC_ICMS',
                               'ALIQ_ICMS', 'VL_ICMS', 'VL_OUTROS')
            self.formato = self.get_formato()

    class registro_C300(TrackedAttributesClass):
        """
        REGISTRO C300: RESUMO DIÁRIO DAS NOTAS FISCAIS DE VENDA A CONSUMIDOR (CÓDIGO 02)
        Este registro deve ser apresentado pelos contribuintes que utilizam notas fiscais de venda ao consumidor, não
        emitidas por ECF. Trata-se de um resumo diário, por série e subsérie do documento fiscal, de todas as operações praticadas.
        Existirão tantos registros C300 quantos forem os agrupamentos de séries e subséries dos documentos fiscais emitidos no
        dia. Os valores de documentos fiscais cancelados não devem ser computados no valor total dos documentos (campo
        VL_DOC).
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C300, self).__init__()
            self.REG = 'C300'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subsérie do documento fiscal
            self.NUM_DOC_INI = ''  # Número do documento fiscal inicial
            self.NUM_DOC_FIN = ''  # Número do documento fiscal final
            self.DT_DOC = ''  # Data da emissão dos documentos fiscais
            self.VL_DOC = ''  # Valor total dos documentos
            self.VL_PIS = ''  # Valor total do PIS
            self.VL_COFINS = ''  # Valor total da COFINS
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada
            self.fieldnames = ('REG', 'COD_MOD', 'SER', 'SUB', 'NUM_DOC_INI', 'NUM_DOC_FIN',
                               'DT_DOC', 'VL_DOC', 'VL_PIS', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C310(TrackedAttributesClass):
        """
        REGISTRO C310: DOCUMENTOS CANCELADOS DE NOTAS FISCAIS DE VENDA A CONSUMIDOR (CÓDIGO 02).
        Este registro tem por objetivo informar os números dos documentos fiscais cancelados.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C310, self).__init__()
            self.REG = 'C310'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C300'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DOC_CANC = ''  # Número do documento fiscal cancelado
            self.fieldnames = ('REG', 'NUM_DOC_CANC')
            self.formato = self.get_formato()

    class registro_C320(TrackedAttributesClass):
        """
        REGISTRO C320: REGISTRO ANALÍTICO DO RESUMO DIÁRIO DAS NOTAS FISCAIS DE VENDA A CONSUMIDOR (CÓDIGO 02).
        Este registro tem por objetivo informar a consolidação diária dos valores das notas fiscais de venda ao
        consumidor, não emitidas por ECF, e deve ser apresentado de forma agrupada na combinação CST_ICMS, CFOP e
        Alíquota de ICMS.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C320, self).__init__()
            self.REG = 'C320'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C300'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor total acumulado das operações correspondentes à combinação de CST_ICMS, CFOP e alíquota do ICMS, incluídas as despesas acessórias e acréscimos.
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS,  referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_ICMS = ''  # Valor acumulado do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_RED_BC = ''  # Valor não tributado em função da redução da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.fieldnames = ('REG', 'CST_ICMS', 'CFOP', 'ALIQ_ICMS', 'VL_OPR', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_RED_BC', 'COD_OBS')
            self.formato = self.get_formato()

    class registro_C321(TrackedAttributesClass):
        """
        REGISTRO C321: ITENS DO RESUMO DIÁRIO DOS DOCUMENTOS (CÓDIGO 02).
        Este registro é o detalhamento, por itens de mercadoria, da consolidação diária dos valores das notas fiscais de
        venda ao consumidor, não emitidas por ECF.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C321, self).__init__()
            self.REG = 'C321'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C320'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.QTD = ''  # Quantidade acumulada do item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = 0.00  # Valor acumulado do item
            self.VL_DESC = ''  # Valor do desconto acumulado
            self.VL_BC_ICMS = 0.0  # Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = 0.0  # Valor acumulado do ICMS debitado
            self.VL_PIS = 0.0  # Valor acumulado do PIS
            self.VL_COFINS = 0.0  # Valor acumulado da COFINS
            self.fieldnames = ('REG', 'COD_ITEM', 'QTD', 'UNID', 'VL_ITEM', 'VL_DESC', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_PIS', 'VL_COFINS')
            self.formato = self.get_formato()

    class registro_C350(TrackedAttributesClass):
        """
        REGISTRO C350: NOTA FISCAL DE VENDA A CONSUMIDOR (CÓDIGO 02)
        Este registro deve ser apresentado pelos contribuintes que utilizam notas fiscais de venda ao consumidor, não
        emitidas por ECF. As notas fiscais canceladas não devem ser informadas.
        Obs.: Os CNPJ e CPF citados neste registro NÃO devem ser informados no registro 01
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C350, self).__init__()
            self.REG = 'C350'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.SER = ''  # Série do documento fiscal
            self.SUB_SER = ''  # Subsérie do documento fiscal
            self.NUM_DOC = ''  # Número do documento fiscal
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.CNPJ_CPF = ''  # CNPJ ou CPF do destinatário
            self.VL_MERC = ''  # Valor das mercadorias constantes no documento
            self.VL_DOC = ''  # Valor total do documento fiscal
            self.VL_DESC = ''  # Valor total do desconto
            self.VL_PIS = ''  # Valor total do PIS
            self.VL_COFINS = ''  # Valor total da COFINS
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada.
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C370(TrackedAttributesClass):
        """
        REGISTRO C370: ITENS DO DOCUMENTO (CÓDIGO 02)
        Este registro é o detalhamento por itens das notas fiscais de venda ao consumidor, modelo 2.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C370, self).__init__()
            self.REG = 'C370'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C350'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''  # Número sequencial do item no documento fiscal
            self.COD_ITEM = ''  # Código do Item (campo 02 do registro 0200)
            self.QTD = ''  # Quantidade do item
            self.UNID = ''  # Unidade do item (campo 02 do registro 0190
            self.VL_ITEM = ''  # Valor total do item
            self.VL_DESC = ''  # Valor total do desconto no item
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C390(TrackedAttributesClass):
        """
        REGISTRO C390 – REGISTRO ANALÍTICO DAS NOTAS FISCAIS DE VENDA A
        CONSUMIDOR (CÓDIGO 02)
        Este registro tem por objetivo informar as notas fiscais de venda ao consumidor, não emitidas por ECF, e deve ser
        apresentado de forma agrupada na combinação CST_ICMS, CFOP e Alíquota de ICMS.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C390, self).__init__()
            self.REG = 'C390'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C350'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor total acumulado das operações correspondentes à combinação de CST_ICMS, CFOP e alíquota do ICMS, incluídas as despesas acessórias e acréscimos.
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_ICMS = ''  # Valor acumulado do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_RED_BC = ''  # Valor não tributado em função da redução da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C400(TrackedAttributesClass):
        """
        REGISTRO C400 - EQUIPAMENTO ECF (CÓDIGO 02 e 2D).
        Este registro tem por objetivo identificar os equipamentos de ECF e deve ser informado por todos os contribuintes
        que utilizem tais equipamentos na emissão de documentos fiscais.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C400, self).__init__()
            self.REG = 'C400'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento conforme a Tabela 4.1.1
            self.ECF_MOD = ''  # Modelo do equipamento
            self.ECF_FAB = ''  # Número de série de fabricação do ECF
            self.ECF_CX = ''  # Número do caixa atribuído ao ECF
            self.fieldnames = ('REG', 'COD_MOD', 'ECF_MOD', 'ECF_FAB', 'ECF_CX')
            self.formato = self.get_formato()

    class registro_C405(TrackedAttributesClass):
        """
        REGISTRO C405 - REDUÇÃO Z (CÓDIGO 02 e 2D).
        Este registro deve ser apresentado com as informações da Redução Z de cada equipamento em funcionamento na
        data das operações de venda à qual se refere a redução. Inclui todos os documentos fiscais totalizados na Redução Z,
        inclusive as operações de venda realizadas durante o período de tolerância do Equipamento ECF.
        Não é apresentado na Entrada.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C405, self).__init__()
            self.REG = 'C405'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C400'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DT_DOC = ''  # Data do movimento a que se refere a Redução Z
            self.CRO = ''  # Posição do Contador de Reinício de Operação
            self.CRZ = ''  # Posição do Contador de Redução Z
            self.NUM_COO_FIN = ''  # Número do Contador de Ordem de Operação do último documento emitido no dia. (Número do COO na Redução Z)
            self.GT_FIN = ''  # Valor do Grande Total final
            self.VL_BRT = ''  # Valor da venda bruta
            self.fieldnames = ('REG', 'DT_DOC', 'CRO', 'CRZ', 'NUM_COO_FIN', 'GT_FIN', 'VL_BRT')
            self.formato = self.get_formato()

    class registro_C410(TrackedAttributesClass):
        """
        REGISTRO C410: PIS E COFINS TOTALIZADOS NO DIA (CÓDIGO 02 e 2D).
        Este registro deve ser apresentado sempre que houver produtos totalizados na Redução Z que acarretem valores de
        PIS e COFINS a serem informados.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C410, self).__init__()
            self.REG = 'C410'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C405'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_PIS = ''  # Valor total do PIS
            self.VL_COFINS = ''  # Valor total da COFINS
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C420(TrackedAttributesClass):
        """
        REGISTRO C420: REGISTRO DOS TOTALIZADORES PARCIAIS DA REDUÇÃO Z (COD 02 e 2D).
        Este registro tem por objetivo discriminar os valores por código de totalizador da Redução Z.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C420, self).__init__()
            self.REG = 'C420'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C405'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_TOT_PAR = ''  # Código do totalizador, conforme Tabela 4.4.6
            self.VLR_ACUM_TOT = ''  # Valor acumulado no totalizador, relativo à respectiva Redução Z.
            self.NR_TOT = ''  # Número do totalizador quando ocorrer mais de uma situação com a mesma carga tributária efetiva.
            self.DESCR_NR_TOT = ''  # Descrição da situação tributária relativa ao totalizador parcial, quando houver mais de um com a mesma carga tributária efetiva.
            self.fieldnames = ('REG', 'COD_TOT_PAR', 'VLR_ACUM_TOT', 'NR_TOT', 'DESCR_NR_TOT')
            self.formato = self.get_formato()

    class registro_C425(TrackedAttributesClass):
        """
        REGISTRO C425: RESUMO DE ITENS DO MOVIMENTO DIÁRIO (CÓDIGO 02 e 2D).
        Este registro tem por objetivo identificar os produtos comercializados na data da movimentação relativa à Redução Z
        informada, sendo obrigatório, quando os totalizadores forem iguais a xxTnnnn, Tnnnn, Fn, In, Nn.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C425, self).__init__()
            self.REG = 'C425'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'C420'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.QTD = ''  # Quantidade acumulada do item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor acumulado do item
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.fieldnames = ('REG', 'COD_ITEM', 'QTD', 'UNID', 'VL_ITEM', 'VL_PIS', 'VL_COFINS')
            self.formato = self.get_formato()

    class registro_C460(TrackedAttributesClass):
        """
        REGISTRO C460: DOCUMENTO FISCAL EMITIDO POR ECF (CÓDIGO 02 e 2D).
        Este registro deve ser apresentado para a identificação dos documentos fiscais emitidos pelos usuários de
        equipamentos ECF, que foram totalizados na Redução Z.
        Para cupom fiscal cancelado, informar somente os campos COD_MOD, COD_SIT e NUM_DOC, sem os
        registros filhos.
        Obs.: Os CNPJ e CPF citados neste registro NÃO devem ser informados no registro 0150.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C460, self).__init__()
            self.REG = 'C460'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C405'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal,apresentaconforme a Tabela 4.1.1
            self.COD_SIT = ''  # Código da situação do documento fiscal,conforme a Tabela 4.1.2
            self.NUM_DOC = ''  # Número do documento fiscal (COO)
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.VL_DOC = ''  # Valor total do documento fiscal
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.CPF_CNPJ = ''  # CPF ou CNPJ do adquirente
            self.NOM_ADQ = ''  # Nome do adquirente
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C470(TrackedAttributesClass):
        """
        REGISTRO C470: ITENS DO DOCUMENTO FISCAL EMITIDO POR ECF (CÓDIGO 02 e 2D).
        Este registro deve ser apresentado para informar os itens dos documentos fiscais emitidos pelos usuários de
        equipamentos ECF, que foram totalizados na Redução Z.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C470, self).__init__()
            self.REG = 'C470'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'C460'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.QTD = ''  # Quantidade do item
            self.QTD_CANC = ''  # Quantidade cancelada, no caso de cancelamento parcial de item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor total do item
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1.
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.ALIQ_ICMS = ''  # Alíquota do ICMS – Carga tributária efetiva em percentual
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C490(TrackedAttributesClass):
        """
        REGISTRO C490: REGISTRO ANALÍTICO DO MOVIMENTO DIÁRIO (CÓDIGO 02 e 2D).
        Este registro tem por objetivo representar a escrituração dos documentos fiscais emitidos por ECF e totalizados
        pela combinação de CST, CFOP e Alíquota.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C490, self).__init__()
            self.REG = 'C490'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C405'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a  Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor da operação correspondente à combinação de CST_ICMS, CFOP, e alíquota do ICMS, incluídas as despesas acessórias e acréscimos
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS,referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_ICMS = ''  # Valor acumulado do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.fieldnames = ('REG', 'CST_ICMS', 'CFOP', 'ALIQ_ICMS', 'VL_OPR', 'VL_BC_ICMS',
                               'VL_ICMS', 'COD_OBS')
            self.formato = self.get_formato()

    class registro_C495(TrackedAttributesClass):
        """
        REGISTRO C495: RESUMO MENSAL DE ITENS DO ECF POR ESTABELECIMENTO (CÓDIGO 02 e 2D).
        Este registro deve ser apresentado pelo contribuinte domiciliado no estado da Bahia, resumindo todas as
        informações num único registro por item de mercadorias, não dispensando a apresentação do registro C400 e registros
        filhos.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C495, self).__init__()
            self.REG = 'C495'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.QTD = ''  # Quantidade acumulada do item
            self.QTD_CANC = ''  # Quantidade cancelada acumulada, no caso de cancelamento parcial de item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor acumulado do item
            self.VL_DESC = ''  # Valor acumulado dos descontos
            self.VL_CANC = ''  # Valor acumulado dos cancelamentos
            self.VL_ACMO = ''  # Valor acumulado dos acréscimos
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor acumulado do ICMS
            self.VL_ISEN = ''  # Valor das saídas isentas do ICMS
            self.VL_NT = ''  # Valor das saídas sob não-incidência ou não-tributadas pelo ICMS
            self.VL_ICMS_ST = ''  # Valor das saídas de mercadorias adquiridas com substituição tributária do ICMS
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C500(TrackedAttributesClass):
        """
        REGISTRO C500: NOTA FISCAL/CONTA DE ENERGIA ELÉTRICA (CÓDIGO 06),NOTA FISCAL/CONTA DE FORNECIMENTO D'ÁGUA CANALIZADA (CÓDIGO 29)
        E NOTA FISCAL CONSUMO FORNECIMENTO DE GÁS (CÓDIGO 28).
        Este registro deve ser apresentado, nas operações de saída, pelos contribuintes do segmento de energia elétrica e
        não obrigadas ao Convênio ICMS 115/03, pelos contribuintes do segmento de fornecimento de gás e, nas operações de
        entrada, por todos os contribuintes adquirentes.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C500, self).__init__()
            self.REG = 'C500'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''  # Indicador do tipo de operação:  0- Entrada; 1- Saída
            self.IND_EMIT = ''  # Indicador do emitente do documento fiscal:  0- Emissão própria; 1- Terceiros
            self.COD_PART = ''  # Código do participante (campo 02 do Registro  0150): - do adquirente, no caso das saídas; - do fornecedor no caso de entradas
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''  # Código da situação do documento fiscal,conforme a Tabela 4.1.2
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subsérie do documento fiscal
            self.COD_CONS = ''  # Código de classe de consumo de energia elétrica ou gás: 01 - Comercial 02 - Consumo Próprio 03 - Iluminação Pública 04 -   Industrial 05 - Poder Público 06 - Residencial 07 - Rural 08 -Serviço Público.Código de classe de consumo de Fornecimento água – Tabela 4.4.2.
            self.NUM_DOC = ''  # Número do documento fiscal
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.DT_E_S = ''  # Data da entrada ou da saída
            self.VL_DOC = ''  # Valor total do documento fiscal
            self.VL_DESC = ''  # Valor total do desconto
            self.VL_FORN = ''  # Valor total fornecido/consumido
            self.VL_SERV_NT = ''  # Valor total dos serviços não-tributados pelo ICMS
            self.VL_TERC = ''  # Valor total cobrado em nome de terceiros
            self.VL_DA = ''  # Valor total de despesas acessórias indicadas no documento fiscal
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor acumulado do ICMS
            self.VL_BC_ICMS_ST = ''  # Valor acumulado da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor acumulado do ICMS retido por  substituição tributária
            self.COD_INF = ''  # Código da informação complementar do documento fiscal (campo 02 do Registro 0450)
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.TP_LIGACAO = ''  # Código de tipo de Ligação 1 - Monofásico 2 - Bifásico 3 - Trifásico
            self.COD_GRUPO_TENSAO = ''  # Código de grupo de tensão: 01 - A1 - Alta Tensão (230kV ou mais) 02 - A2 - Alta Tensão (88 a 138kV)
            # 03 - A3 - Alta Tensão (69kV)
            # 04 - A3a - Alta Tensão (30kV a 44kV)
            #05 - A4 - Alta Tensão (2,3kV a 25kV)
            #06 - AS - Alta Tensão Subterrâneo 06
            #07 - B1 - Residencial
            #08 - B1 - Residencial Baixa Renda 08
            #09 - B2 - Rural 09
            #10 - B2 - Cooperativa de Eletrificação Rural
            #11 - B2 - Serviço Público de Irrigação
            #12 - B3 - Demais Classes
            #13 - B4a - Iluminação Pública - rede de distribuição
            #14 - B4b - Iluminação Pública - bulbo de lâmpada
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'COD_CONS', 'NUM_DOC', 'DT_DOC', 'DT_E_S', 'VL_DOC',
                               'VL_DESC', 'VL_FORN', 'VL_SERV_NT', 'VL_TERC', 'VL_DA', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_BC_ICMS_ST', 'VL_ICMS_ST', 'COD_INF', 'VL_PIS',
                               'VL_COFINS', 'TP_LIGACAO', 'COD_GRUPO_TENSAO')
            self.formato = self.get_formato()

    class registro_C510(TrackedAttributesClass):
        """
        REGISTRO C510: ITENS DO DOCUMENTO NOTA FISCAL/CONTA ENERGIA ELÉTRICA (CÓDIGO 06), NOTA FISCAL/CONTA DE FORNECIMENTO D'ÁGUA
        CANALIZADA (CÓDIGO 29) E NOTA FISCAL/CONTA DE FORNECIMENTO DE GÁS (CÓDIGO 28).
        Este registro deve ser apresentado para informar os itens das Notas Fiscais/Contas de Energia Elétrica (código 06
        da Tabela Documentos Fiscais do ICMS), Notas Fiscais/Contas de fornecimento de água canalizada (código 29) e Notas
        Fiscais Consumo Fornecimento de Gás (código 28 da Tabela Documentos Fiscais do ICMS), nas operações de saída
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C510, self).__init__()
            self.REG = 'C510'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''  # Número sequencial do item no documento fiscal
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.COD_CLASS = ''  # Código de classificação do item de energia elétrica, conforme a Tabela 4.4.1
            self.QTD = ''  # Quantidade do item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor do item
            self.VL_DESC = ''  # Valor total do desconto
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação
            self.VL_BC_ICMS = ''  # Valor da base de cálculo do ICMS
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_ICMS = ''  # Valor do ICMS creditado/debitado
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo referente à substituição tributária
            self.ALIQ_ST = ''  # Alíquota do ICMS da substituição tributária na unidade da federação de destino
            self.VL_ICMS_ST = ''  # Valor do ICMS referente à substituição tributária
            self.IND_REC = ''  # Indicador do tipo de receita: 0- Receita própria; 1- Receita de terceiros
            self.COD_PART = ''  # Código do participante receptor da receita, terceiro da operação (campo 02 do Registro 0150)
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C590(TrackedAttributesClass):
        """
        REGISTRO C590: REGISTRO ANALÍTICO DO DOCUMENTO - NOTA FISCAL/CONTA DE ENERGIA ELÉTRICA (CÓDIGO 06), NOTA FISCAL/CONTA
        DE FORNECIMENTO D'ÁGUA CANALIZADA (CÓDIGO 29) E NOTA FISCAL CONSUMO FORNECIMENTO DE GÁS (CÓDIGO 28).
        Este registro representa a escrituração dos documentos fiscais dos modelos especificados no C500, totalizados
        pelo agrupamento das combinações dos valores de CST, CFOP e Alíquota dos itens de cada documento. Deve haver um
        registro C590 com os totais de cada combinação de valores de CST, CFOP e Alíquota, informados nos itens do registro
        C510. Obs.: Nas operações de entradas, informar o CST que constar no documento fiscal de aquisição dos produtos
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C590, self).__init__()
            self.REG = 'C590'  # Texto fixo contendo
            self.nivel_h = 3  # nível            self.pai=''
            self.pai = 'C500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1.
            self.CFOP = ''  # Código Fiscal de Operação e Prestação do agrupamento de itens
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor da operação correspondente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_BC_ICMS = ''  # Parcela correspondente ao "Valor da base de cálculo do ICMS" referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_ICMS = ''  # Parcela correspondente ao "Valor do ICMS" referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_BC_ICMS_ST = ''  # Parcela correspondente ao "Valor da base de cálculo do ICMS" da substituição tributária referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_ICMS_ST = ''  # Parcela correspondente ao valor creditado/debitado do ICMS da substituição tributária, referente à combinação de CST_ICMS,CFOP e alíquota do ICMS.
            self.VL_RED_BC = ''  # Valor não tributado em função da redução da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.fieldnames = ('REG', 'CST_ICMS', 'CFOP', 'ALIQ_ICMS', 'VL_OPR', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_BC_ICMS_ST', 'VL_ICMS_ST', 'VL_RED_BC', 'COD_OBS')
            self.formato = self.get_formato()

    class registro_C600(TrackedAttributesClass):
        """
        REGISTRO C600: CONSOLIDAÇÃO DIÁRIA DE NOTAS FISCAIS/CONTAS DE ENERGIA ELÉTRICA (CÓDIGO 06), NOTA FISCAL/CONTA DE FORNECIMENTO
        D'ÁGUA CANALIZADA (CÓDIGO 29) E NOTA FISCAL/CONTA DE FORNECIMENTO DE GÁS (CÓDIGO 28) (EMPRESAS NÃO OBRIGADAS AO
        CONVÊNIO ICMS 115/03). Este registro deve ser apresentado na consolidação diária de Notas Fiscais/Conta de Energia Elétrica (código 06 da
        Tabela Documentos Fiscais do ICMS), Notas Fiscais de Fornecimento D’Água (código 29 da Tabela Documentos Fiscais
        do ICMS) e Notas Fiscais/Conta de Fornecimento de Gás (código 28 da Tabela Documentos Fiscais do ICMS) para
        empresas não obrigadas ao Convênio ICMS 115/2003.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C600, self).__init__()
            self.REG = 'C600'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal, apresentar conforme a Tabela 4.1.1
            self.COD_MUN = ''  # Código do município dos pontos de consumo,conforme a tabela IBGE
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subsérie do documento fiscal
            self.COD_CONS = ''  # Código de classe de consumo de energia elétrica ou gás: 01 - Comercial 02 - Consumo Próprio 03 - Iluminação Pública 04 - Industrial 05 - Poder Público 06 - Residencial 07 - Rural 08 -Serviço Público.  Código de classe de consumo de Fornecimento de ́água – Tabela 4.4.2.
            self.QTD_CONS = ''  # Quantidade de documentos consolidados neste registro
            self.QTD_CANC = ''  # Quantidade de documentos cancelados
            self.DT_DOC = ''  # Data dos documentos consolidados
            self.VL_DOC = ''  # Valor total dos documentos
            self.VL_DESC = ''  # Valor acumulado dos descontos
            self.CONS = ''  # Consumo total acumulado, em kWh (Código 06)
            self.VL_FORN = ''  # Valor acumulado do fornecimento
            self.VL_SERV_NT = ''  # Valor acumulado dos serviços não-tributados pelo ICMS
            self.VL_TERC = ''  # Valores cobrados em nome de terceiros
            self.VL_DA = ''  # Valor acumulado das despesas acessórias
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor acumulado do ICMS
            self.VL_BC_ICMS_ST = ''  # Valor acumulado da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor acumulado do ICMS retido por substituição tributária
            self.VL_PIS = ''  # Valor acumulado do PIS
            self.VL_COFINS = ''  # Valor acumulado COFINS
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C601(TrackedAttributesClass):
        """
        REGISTRO C601: DOCUMENTOS CANCELADOS - CONSOLIDAÇÃO DIÁRIA DE NOTAS FISCAIS/CONTAS DE ENERGIA ELÉTRICA (CÓDIGO 06), NOTA
        FISCAL/CONTA DE FORNECIMENTO D'ÁGUA CANALIZADA (CÓDIGO 29) E NOTA FISCAL/CONTA DE FORNECIMENTO DE GÁS (CÓDIGO 28)
        Este registro tem por objetivo informar a numeração dos documentos cancelados da consolidação diária dos
        documentos fiscais do C600.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C601, self).__init__()
            self.REG = 'C601'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C600'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DOC_CANC = ''  # Número do documento fiscal cancelado
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C610(TrackedAttributesClass):
        """
        REGISTRO C610: ITENS DO DOCUMENTO CONSOLIDADO (CÓDIGO 06), NOTA FISCAL/CONTA DE FORNECIMENTO D'ÁGUA CANALIZADA (CÓDIGO 29) E
        NOTA FISCAL/CONTA DE FORNECIMENTO DE GÁS (CÓDIGO 28) (EMPRESAS NÃO OBRIGADAS AO CONVÊNIO ICMS 115/03).
        Este registro tem por objetivo discriminar por item os registros consolidados apresentados no C600.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C610, self).__init__()
            self.REG = 'C610'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C600'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_CLASS = ''  # Código de classificação do item de energia elétrica, conforme Tabela 4.4.1
            self.COD_ITEM = ''  # Código do item (campo 02 do Registro 0200)
            self.QTD = ''  # Quantidade acumulada do item
            self.UNID = ''  # Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''  # Valor acumulado do item
            self.VL_DESC = ''  # Valor acumulado dos descontos
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme aTabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação conforme tabela indicada no item 4.2.2.
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor acumulado do ICMS debitado
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor do ICMS retido por substituição tributária
            self.VL_PIS = ''  # Valor do PIS
            self.VL_COFINS = ''  # Valor da COFINS
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C690(TrackedAttributesClass):
        """
        REGISTRO C690: REGISTRO ANALÍTICO DOS DOCUMENTOS (NOTAS
        FISCAIS/CONTAS DE ENERGIA ELÉTRICA (CÓDIGO 06), NOTA FISCAL/CONTA
        DE FORNECIMENTO D’ÁGUA CANALIZADA (CÓDIGO 29) E NOTA
        FISCAL/CONTA DE FORNECIMENTO DE GÁS (CÓDIGO 28)
        Este registro tem por objetivo representar a escrituração dos documentos fiscais dos modelos especificados no
        C600, totalizados pelo agrupamento das combinações dos valores de CST, CFOP e Alíquota dos itens de cada registro
        consolidado. Existirá um registro C690 para cada combinação de valores de CST, CFOP e Alíquota que existir nos itens
        (registro C610), totalizando estes itens.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C690, self).__init__()
            self.REG = 'C690'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C600'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a tabela
            self.CFOP = ''  # Código Fiscal de Operação e Prestação, conforme a tabela indicada no item 4.2.2
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor da operação correspondente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_BC_ICMS = ''  # Parcela correspondente ao "Valor da base de cálculo do ICMS" referente à combinação CST_ICMS, CFOP e alíquota do ICMS
            self.VL_ICMS = ''  # Parcela correspondente ao "Valor do ICMS" referente à combinação CST_ICMS, CFOP e alíquota do ICMS
            self.VL_RED_BC = ''  # Valor não tributado em função da redução da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor do ICMS retido por substituição tributária
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C700(TrackedAttributesClass):
        """
        REGISTRO C700: CONSOLIDAÇÃO DOS DOCUMENTOS NF/CONTA ENERGIA ELÉTRICA (CÓD 06), EMITIDAS EM VIA ÚNICA (EMPRESAS OBRIGADAS À ENTREGA
        DO ARQUIVO PREVISTO NO CONVÊNIO ICMS 115/03) ) E NOTA FISCAL/CONTA DE FORNECIMENTO DE GÁS CANALIZADO (CÓDIGO 28)
        Este registro deve ser apresentado com a consolidação das Notas Fiscais/Conta de Energia Elétrica (código 06 da
        Tabela Documentos Fiscais do ICMS) pelas empresas obrigadas à entrega do arquivo previsto no Convênio ICMS
        115/2003. Para as unidades federadas que utilizam o leiaute do Convênio ICMS 115/2003 para as informações das empresas
        fornecedoras de gás canalizado, deverá ser utilizado este registro.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C700, self).__init__()
            self.REG = 'C700'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal,conforme a Tabela 4.1.1
            self.SER = ''  # Série do documento fiscal
            self.NRO_ORD_INI = ''  # Número de ordem inicial
            self.NRO_ORD_FIN = ''  # Número de ordem final
            self.DT_DOC_INI = ''  # Data de emissão inicial dos documentos / Data inicial de vencimento da fatura
            self.DT_DOC_FIN = ''  # Data de emissão final dos documentos / Data final do vencimento da fatura
            self.NOM_MEST = ''  # Nome do arquivo Mestre de Documento Fiscal
            self.CHV_COD_DIG = ''  # Chave de codificação digital do arquivo Mestre de Documento Fiscal
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C790(TrackedAttributesClass):
        """
        REGISTRO C790: REGISTRO ANALÍTICO DOS DOCUMENTOS (CÓDIGO 06).
        Este registro representa a escrituração dos documentos fiscais dos modelos especificados no C700, totalizados
        pelo agrupamento das combinações dos valores de CST, CFOP e Alíquota dos itens de cada registro consolidado.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C790, self).__init__()
            self.REG = 'C790'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C700'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação, conforme a tabela indicada no item 4.2.2
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor da operação correspondente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_BC_ICMS = ''  # Parcela correspondente ao "Valor da base de cálculo do ICMS" referente à combinação CST_ICMS, CFOP, e alíquota do ICMS
            self.VL_ICMS = ''  # Parcela correspondente ao "Valor do ICMS" referente à combinação CST_ICMS, CFOP e alíquota do ICMS
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo do ICMS substituiçãotributária
            self.VL_ICMS_ST = ''  # Valor do ICMS retido por substituição tributária
            self.VL_RED_BC = ''  # Valor não tributado em função da redução da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP e alíquota do ICMS..
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do Registro 0460)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C791(TrackedAttributesClass):
        """
        REGISTRO C791: REGISTRO DE INFORMAÇÕES DE ST POR UF (COD 06)
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C791, self).__init__()
            self.REG = 'C791'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'C790'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.UF = ''  # Sigla da unidade da federação a que se refere a retenção ST
            self.VL_BC_ICMS_ST = ''  # Valor da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''  # Valor do ICMS retido por substituição tributária
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C800(TrackedAttributesClass):
        """
        REGISTRO C800: CUPOM FISCAL ELETRÔNICO (CÓDIGO 59)
        Este registro deve ser gerado para cada CF-e (Código 59) emitido por equipamento SAT-CF-e, conforme Ajuste
        SINIEF no 11, de 24 de setembro de 2010. Não poderão ser informados dois ou mais registros com a mesma combinação de COD_SIT + NUM_CFE +
        NUM_SAT.Para cupom fiscal eletrônico cancelado, informar somente os campos REG, COD_MOD, COD_SIT, NUM_CFE,
        NR_SAT e CHV_CFE
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C800, self).__init__()
            self.REG = 'C800'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''  # Código da situação do documento fiscal, conforme a  Tabela 4.1.2
            self.NUM_CFE = ''  # Número do Cupom Fiscal Eletrônico
            self.DT_DOC = ''  # Data da emissão do Cupom Fiscal Eletrônico
            self.VL_CFE = ''  # Valor total do Cupom Fiscal Eletrônico
            self.VL_PIS = ''  # Valor total do PIS
            self.VL_COFINS = ''  # Valor total da COFINS
            self.CNPJ_CPF = ''  # CNPJ ou CPF do destinatário
            self.NR_SAT = ''  # Número de Série do equipamento SAT
            self.CHV_CFE = ''  # Chave do Cupom Fiscal Eletrônico
            self.VL_DESC = ''  # Valor total de descontos
            self.VL_MERC = ''  # Valor total das mercadorias e serviços
            self.VL_OUT_DA = ''  # Valor total de outras despesas acessórias e acréscimos
            self.VL_ICMS = ''  # Valor do ICMS
            self.VL_PIS_ST = ''  # Valor total do PIS retido por subst. trib.
            self.VL_COFINS_ST = ''  # Valor total da COFINS retido por subst. trib.
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C850(TrackedAttributesClass):
        """
        REGISTRO C850: REGISTRO ANALÍTICO DO CF-E (CODIGO 59)
        Este registro tem por objetivo representar a escrituração do CF-e (código 59) segmentado por CST, CFOP e Alíquota do ICMS.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C850, self).__init__()
            self.REG = 'C850'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C800'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação do agrupamento de itens
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor total do CF-e” na combinação de CST_ICMS, CFOP e alíquota do ICMS, correspondente ao somatório do valor líquido dos itens.
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP, e alíquota do ICMS.
            self.VL_ICMS = ''  # Parcela correspondente ao "Valor do ICMS" referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do   registro 0460)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C860(TrackedAttributesClass):
        """
        REGISTRO C860: IDENTIFICAÇÃO DO EQUIPAMENTO SAT-CF-E
        Este registro tem por objetivo identificar os equipamentos SAT-CF-e e deve ser informado por todos os
        contribuintes que utilizem tais equipamentos na emissão de documentos fiscais.
        Não poderão ser informados dois ou mais registros com a mesma combinação COD_MOD, NR_SAT, DOC_INI e
        DOC_FIM.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C860, self).__init__()
            self.REG = 'C860'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'C001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela  4.1.1
            self.NR_SAT = ''  # Número de Série do equipamento SAT
            self.DT_DOC = ''  # Data de emissão dos documentos fiscais
            self.DOC_INI = ''  # Número do documento inicial
            self.DOC_FIM = ''  # Número do documento final
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C890(TrackedAttributesClass):
        """
        REGISTRO C890: RESUMO DIÁRIO DO CF-E (CÓDIGO 59) POR EQUIPAMENTO SAT- CF-E
        Este registro tem por objetivo promover a consolidação dos CF-e emitidos no período, por equipamento SAT-CF-e.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C890, self).__init__()
            self.REG = 'C890'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'C860'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''  # Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''  # Código Fiscal de Operação e Prestação do agrupamento de itens
            self.ALIQ_ICMS = ''  # Alíquota do ICMS
            self.VL_OPR = ''  # Valor total do CF-e” na combinação de CST_ICMS, CFOP e ALÍQUOTA DO ICMS, correspondente ao somatório do valor líquido dos itens.
            self.VL_BC_ICMS = ''  # Valor acumulado da base de cálculo do ICMS, referente à combinação de CST_ICMS, CFOP e ALÍQUOTA DO ICMS.
            self.VL_ICMS = ''  # Parcela correspondente ao "Valor do ICMS" referente à combinação de CST_ICMS, CFOP e alíquota do ICMS.
            self.COD_OBS = ''  # Código da observação do lançamento fiscal (campo 02 do registro 0460)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_C990(TrackedAttributesClass):
        """
        REGISTRO C990: ENCERRAMENTO DO BLOCO C
        Este registro destina-se a identificar o encerramento do bloco C e informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C990, self).__init__()
            self.REG = 'C990'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN_C = ''
            self.fieldnames = ('REG', 'QTD_LIN_C')
            self.formato = self.get_formato()


