# -*- coding: utf-8 -*-

from ..utils import *


class bloco_g(TrackedAttributesClass):
    """
    BLOCO G – CONTROLE DO CRÉDITO DE ICMS DO ATIVO PERMANENTE CIAP
    Bloco de registros dos dados relativos ao CIAP.
    """

    class registro_G001(TrackedAttributesClass):
        """
        REGISTRO G001: ABERTURA DO BLOCO G
        Este registro deve ser gerado para abertura do Bloco G, indicando se há registros de informações no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G001, self).__init__()
            self.REG = 'G001'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = ''  # Indicador de movimento:0- Bloco com dados informados;1- Bloco sem dados informados.
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_G110(TrackedAttributesClass):
        """
        REGISTRO G110 – ICMS – ATIVO PERMANENTE – CIAP
        Este registro tem o objetivo de prestar informações sobre o CIAP:
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G110, self).__init__()
            self.REG = 'G110'  # Texto fixo contendo.
            self.nivel_h = 2  # nível
            self.pai = 'G001'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.DT_INI = ''
            self.DT_FIN = ''
            self.SALDO_IN_ICMS = ''
            self.SOM_PARC = ''
            self.VL_TRIB_EXP = ''
            self.VL_TOTAL = ''
            self.IND_PER_SAI = ''
            self.ICMS_APROP = ''
            self.SOM_ICMS_OC = ''
            self.fieldnames = ('REG', 'DT_INI', 'DT_FIN', 'SALDO_IN_ICMS', 'SOM_PARC',
                               'VL_TRIB_EXP', 'VL_TOTAL', 'IND_PER_SAI', 'ICMS_APROP',
                               'SOM_ICMS_OC')
            self.formato = self.get_formato()

    class registro_G125(TrackedAttributesClass):
        """
        REGISTRO G125 – MOVIMENTAÇÃO DE BEM OU COMPONENTE DO ATIVO IMOBILIZADO
        Este registro tem o objetivo de informar as movimentações de bens ou componentes no CIAP e a apropriação de
        parcelas de créditos de ICMS do Ativo Imobilizado.
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G125, self).__init__()
            self.REG = 'G125'  # Texto fixo contendo.
            self.nivel_h = 3  # nível
            self.pai = 'G110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_IND_BEM = ''
            self.DT_MOV = ''
            self.TIPO_MOV = ''
            self.VL_IMOB_ICMS_OP = ''
            self.VL_IMOB_ICMS_ST = ''
            self.VL_IMOB_ICMS_FRT = ''
            self.VL_IMOB_ICMS_DIF = ''
            self.NUM_PARC = ''
            self.VL_PARC_PASS = ''
            self.fieldnames = ('REG', 'COD_IND_BEM', 'DT_MOV', 'TIPO_MOV', 'VL_IMOB_ICMS_OP',
                               'VL_IMOB_ICMS_ST', 'VL_IMOB_ICMS_FRT', 'VL_IMOB_ICMS_DIF',
                               'NUM_PARC', 'VL_PARC_PASS')
            self.formato = self.get_formato()

    class registro_G126(TrackedAttributesClass):
        """
        REGISTRO G126 –OUTROS CRÉDITOS CIAP
        Este registro tem por objetivo discriminar os demais valores a serem apropriados como créditos de ICMS de Ativo
        Imobilizado que não foram escriturados nos períodos anteriores, quando a legislação permitir.
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G126, self).__init__()
            self.REG = 'G126'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'G125'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DT_INI = ''
            self.DT_FIM = ''
            self.NUM_PARC = ''
            self.VL_PARC_PASS = ''
            self.VL_TRIB_OC = ''
            self.VL_TOTAL = ''
            self.IND_PER_SAI = ''
            self.VL_PARC_APROP = ''
            self.fieldnames = ('REG', 'DT_INI', 'DT_FIM', 'NUM_PARC', 'VL_PARC_PASS', 'VL_TRIB_OC',
                               'VL_TOTAL', 'IND_PER_SAI')
            self.formato = self.get_formato()

    class registro_G130(TrackedAttributesClass):
        """
        REGISTRO G130 – IDENTIFICAÇÃO DO DOCUMENTO FISCAL
        Este registro tem o objetivo de identificar o documento fiscal que acobertou a entrada ou a saída do bem ou
        componente do CIAP.
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G130, self).__init__()
            self.REG = 'G130'  # Texto fixo contendo.
            self.nivel_h = 4  # nível
            self.pai = 'G125'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_EMIT = ''
            self.COD_PART = ''
            self.COD_MOD = ''
            self.SERIE = ''
            self.NUM_DOC = ''
            self.CHV_NFE_CTE = ''
            self.DT_DOC = ''
            self.fieldnames = ('REG', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'SERIE', 'NUM_DOC',
                               'CHV_NFE_CTE', 'DT_DOC')
            self.formato = self.get_formato()

    class registro_G140(TrackedAttributesClass):
        """
        REGISTRO G140 – IDENTIFICAÇÃO DO ITEM DO DOCUMENTO FISCAL
        Este registro tem o objetivo de identificar o item do documento fiscal informado no registro G130.
        Não podem ser informados dois ou mais registros com o mesmo valor no campo NUM_ITEM + COD_ITEM.
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G140, self).__init__()
            self.REG = 'G140'  # Texto fixo contendo.
            self.nivel_h = 5  # nível
            self.pai = 'G130'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''
            self.COD_ITEM = ''
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM')
            self.formato = self.get_formato()

    class registro_G990(TrackedAttributesClass):
        """
        REGISTRO G990: ENCERRAMENTO DO BLOCO G
        Este registro deve ser gerado para o encerramento do Bloco G e indica o número total de registros existentes neste Bloco
        """
        _order = []

        def __init__(self):
            super(bloco_g.registro_G990, self).__init__()
            self.REG = 'G990'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN_G = ''
            self.fieldnames = ('REG', 'QTD_LIN_G')
            self.formato = self.get_formato()
