# -*- coding: utf-8 -*-

from ..utils import *


class bloco_h(TrackedAttributesClass):
    """
    BLOCO H: INVENTÁRIO FÍSICO
    Este bloco destina-se a informar o inventário físico do estabelecimento, nos casos e prazos previstos na legislação
    pertinente.
    """


    class registro_H001(TrackedAttributesClass):
        """
        REGISTRO H001: ABERTURA DO BLOCO H
        Este registro deve ser gerado para abertura do Bloco H, indicando se há registros de informações no bloco.
        """

        _order = []

        def __init__(self):
            super(bloco_h.registro_H001, self).__init__()
            self.REG = 'H001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = ''
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()


    class registro_H005(TrackedAttributesClass):
        """
        REGISTRO H005: TOTAIS DO INVENTÁRIO
        Este registro deve ser apresentado para discriminar os valores totais dos itens/produtos do inventário realizado em
        31 de dezembro de cada exercício, ou nas demais datas estabelecidas pela legislação fiscal ou comercial. O inventário
        deverá ser apresentado no arquivo da EFD, no segundo mês subsequente ao evento. Ex. inventário realizado em 31/12/08
        deverá ser apresentado na EFD de período de referência fevereiro de 2009.
        Atribuir valor Zero ao inventário significa escriturar sem estoque.
        """
        _order = []

        def __init__(self):
            super(bloco_h.registro_H005, self).__init__()
            self.REG = 'H005'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'H001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DT_INV = ''
            self.VL_INV = ''
            self.MOT_INV = ''
            self.fieldnames = ('REG', 'DT_INV', 'VL_INV', 'MOT_INV')
            self.formato = self.get_formato()

    class registro_H010(TrackedAttributesClass):
        """
        REGISTRO H010: INVENTÁRIO.
        Este registro deve ser informado para discriminar os itens existentes no estoque. Este registro não pode ser fornecido se o
        campo 03 (VL_INV) do registro H005 for igual a “0” (zero).
        """
        _order = []

        def __init__(self):
            super(bloco_h.registro_H010, self).__init__()
            self.REG = 'H010'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'H005'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_ITEM = ''
            self.UNID = ''
            self.QTD = ''
            self.VL_UNIT = ''
            self.VL_ITEM = ''
            self.IND_PROP = ''
            self.COD_PART = ''
            self.TXT_COMPL = ''
            self.COD_CTA = ''
            self.VL_ITEM_IR = ''
            self.fieldnames = ('REG', 'COD_ITEM', 'UNID', 'QTD', 'VL_UNIT', 'VL_ITEM', 'IND_PROP',
                               'COD_PART', 'TXT_COMPL', 'COD_CTA', 'VL_ITEM_IR')
            self.formato = self.get_formato()

    class registro_H020(TrackedAttributesClass):
        _order = []

        def __init__(self):
            super(bloco_h.registro_H020, self).__init__()
            self.REG = 'H020'
            self.nivel_h = 4
            self.pai = 'H020'
            self.ocorrencia = 'N'
            self.CST_ICMS = ''
            self.BC_ICMS = ''
            self.fieldnames = ('REG', 'CST_ICMS', 'BC_ICMS', 'VL_ICMS')
            self.formato = self.get_formato()


    class registro_H990(TrackedAttributesClass):
        """
        REGISTRO H990: ENCERRAMENTO DO BLOCO H.
        Este registro destina-se a identificar o encerramento do bloco H e a informar a quantidade de linhas (registros)
        existentes no bloco
        """

        _order = []

        def __init__(self):
            super(bloco_h.registro_H990, self).__init__()
            self.REG = 'H990'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.QTD_LIN_H = ''
            self.fieldnames = ('REG', 'QTD_LIN_H')
            self.formato = self.get_formato()

